// Code generated by protoc-gen-go. DO NOT EDIT.
// versions:
// 	protoc-gen-go v1.36.1
// 	protoc        v5.29.2
// source: tflint.proto

package proto

import (
	protoreflect "google.golang.org/protobuf/reflect/protoreflect"
	protoimpl "google.golang.org/protobuf/runtime/protoimpl"
	reflect "reflect"
	sync "sync"
)

const (
	// Verify that this generated code is sufficiently up-to-date.
	_ = protoimpl.EnforceVersion(20 - protoimpl.MinVersion)
	// Verify that runtime/protoimpl is sufficiently up-to-date.
	_ = protoimpl.EnforceVersion(protoimpl.MaxVersion - 20)
)

type ModuleCtxType int32

const (
	ModuleCtxType_MODULE_CTX_TYPE_UNSPECIFIED ModuleCtxType = 0
	ModuleCtxType_MODULE_CTX_TYPE_SELF        ModuleCtxType = 1
	ModuleCtxType_MODULE_CTX_TYPE_ROOT        ModuleCtxType = 2
)

// Enum value maps for ModuleCtxType.
var (
	ModuleCtxType_name = map[int32]string{
		0: "MODULE_CTX_TYPE_UNSPECIFIED",
		1: "MODULE_CTX_TYPE_SELF",
		2: "MODULE_CTX_TYPE_ROOT",
	}
	ModuleCtxType_value = map[string]int32{
		"MODULE_CTX_TYPE_UNSPECIFIED": 0,
		"MODULE_CTX_TYPE_SELF":        1,
		"MODULE_CTX_TYPE_ROOT":        2,
	}
)

func (x ModuleCtxType) Enum() *ModuleCtxType {
	p := new(ModuleCtxType)
	*p = x
	return p
}

func (x ModuleCtxType) String() string {
	return protoimpl.X.EnumStringOf(x.Descriptor(), protoreflect.EnumNumber(x))
}

func (ModuleCtxType) Descriptor() protoreflect.EnumDescriptor {
	return file_tflint_proto_enumTypes[0].Descriptor()
}

func (ModuleCtxType) Type() protoreflect.EnumType {
	return &file_tflint_proto_enumTypes[0]
}

func (x ModuleCtxType) Number() protoreflect.EnumNumber {
	return protoreflect.EnumNumber(x)
}

// Deprecated: Use ModuleCtxType.Descriptor instead.
func (ModuleCtxType) EnumDescriptor() ([]byte, []int) {
	return file_tflint_proto_rawDescGZIP(), []int{0}
}

type SchemaMode int32

const (
	SchemaMode_SCHEMA_MODE_UNSPECIFIED     SchemaMode = 0
	SchemaMode_SCHEMA_MODE_DEFAULT         SchemaMode = 1
	SchemaMode_SCHEMA_MODE_JUST_ATTRIBUTES SchemaMode = 2
)

// Enum value maps for SchemaMode.
var (
	SchemaMode_name = map[int32]string{
		0: "SCHEMA_MODE_UNSPECIFIED",
		1: "SCHEMA_MODE_DEFAULT",
		2: "SCHEMA_MODE_JUST_ATTRIBUTES",
	}
	SchemaMode_value = map[string]int32{
		"SCHEMA_MODE_UNSPECIFIED":     0,
		"SCHEMA_MODE_DEFAULT":         1,
		"SCHEMA_MODE_JUST_ATTRIBUTES": 2,
	}
)

func (x SchemaMode) Enum() *SchemaMode {
	p := new(SchemaMode)
	*p = x
	return p
}

func (x SchemaMode) String() string {
	return protoimpl.X.EnumStringOf(x.Descriptor(), protoreflect.EnumNumber(x))
}

func (SchemaMode) Descriptor() protoreflect.EnumDescriptor {
	return file_tflint_proto_enumTypes[1].Descriptor()
}

func (SchemaMode) Type() protoreflect.EnumType {
	return &file_tflint_proto_enumTypes[1]
}

func (x SchemaMode) Number() protoreflect.EnumNumber {
	return protoreflect.EnumNumber(x)
}

// Deprecated: Use SchemaMode.Descriptor instead.
func (SchemaMode) EnumDescriptor() ([]byte, []int) {
	return file_tflint_proto_rawDescGZIP(), []int{1}
}

type ErrorCode int32

const (
	ErrorCode_ERROR_CODE_UNSPECIFIED ErrorCode = 0
	ErrorCode_ERROR_CODE_SENSITIVE   ErrorCode = 4
)

// Enum value maps for ErrorCode.
var (
	ErrorCode_name = map[int32]string{
		0: "ERROR_CODE_UNSPECIFIED",
		4: "ERROR_CODE_SENSITIVE",
	}
	ErrorCode_value = map[string]int32{
		"ERROR_CODE_UNSPECIFIED": 0,
		"ERROR_CODE_SENSITIVE":   4,
	}
)

func (x ErrorCode) Enum() *ErrorCode {
	p := new(ErrorCode)
	*p = x
	return p
}

func (x ErrorCode) String() string {
	return protoimpl.X.EnumStringOf(x.Descriptor(), protoreflect.EnumNumber(x))
}

func (ErrorCode) Descriptor() protoreflect.EnumDescriptor {
	return file_tflint_proto_enumTypes[2].Descriptor()
}

func (ErrorCode) Type() protoreflect.EnumType {
	return &file_tflint_proto_enumTypes[2]
}

func (x ErrorCode) Number() protoreflect.EnumNumber {
	return protoreflect.EnumNumber(x)
}

// Deprecated: Use ErrorCode.Descriptor instead.
func (ErrorCode) EnumDescriptor() ([]byte, []int) {
	return file_tflint_proto_rawDescGZIP(), []int{2}
}

type GetModuleContent_ExpandMode int32

const (
	GetModuleContent_EXPAND_MODE_UNSPECIFIED GetModuleContent_ExpandMode = 0
	GetModuleContent_EXPAND_MODE_NONE        GetModuleContent_ExpandMode = 1
	GetModuleContent_EXPAND_MODE_EXPAND      GetModuleContent_ExpandMode = 2
)

// Enum value maps for GetModuleContent_ExpandMode.
var (
	GetModuleContent_ExpandMode_name = map[int32]string{
		0: "EXPAND_MODE_UNSPECIFIED",
		1: "EXPAND_MODE_NONE",
		2: "EXPAND_MODE_EXPAND",
	}
	GetModuleContent_ExpandMode_value = map[string]int32{
		"EXPAND_MODE_UNSPECIFIED": 0,
		"EXPAND_MODE_NONE":        1,
		"EXPAND_MODE_EXPAND":      2,
	}
)

func (x GetModuleContent_ExpandMode) Enum() *GetModuleContent_ExpandMode {
	p := new(GetModuleContent_ExpandMode)
	*p = x
	return p
}

func (x GetModuleContent_ExpandMode) String() string {
	return protoimpl.X.EnumStringOf(x.Descriptor(), protoreflect.EnumNumber(x))
}

func (GetModuleContent_ExpandMode) Descriptor() protoreflect.EnumDescriptor {
	return file_tflint_proto_enumTypes[3].Descriptor()
}

func (GetModuleContent_ExpandMode) Type() protoreflect.EnumType {
	return &file_tflint_proto_enumTypes[3]
}

func (x GetModuleContent_ExpandMode) Number() protoreflect.EnumNumber {
	return protoreflect.EnumNumber(x)
}

// Deprecated: Use GetModuleContent_ExpandMode.Descriptor instead.
func (GetModuleContent_ExpandMode) EnumDescriptor() ([]byte, []int) {
	return file_tflint_proto_rawDescGZIP(), []int{11, 0}
}

type EmitIssue_Severity int32

const (
	EmitIssue_SEVERITY_UNSPECIFIED EmitIssue_Severity = 0
	EmitIssue_SEVERITY_ERROR       EmitIssue_Severity = 1
	EmitIssue_SEVERITY_WARNING     EmitIssue_Severity = 2
	EmitIssue_SEVERITY_NOTICE      EmitIssue_Severity = 3
)

// Enum value maps for EmitIssue_Severity.
var (
	EmitIssue_Severity_name = map[int32]string{
		0: "SEVERITY_UNSPECIFIED",
		1: "SEVERITY_ERROR",
		2: "SEVERITY_WARNING",
		3: "SEVERITY_NOTICE",
	}
	EmitIssue_Severity_value = map[string]int32{
		"SEVERITY_UNSPECIFIED": 0,
		"SEVERITY_ERROR":       1,
		"SEVERITY_WARNING":     2,
		"SEVERITY_NOTICE":      3,
	}
)

func (x EmitIssue_Severity) Enum() *EmitIssue_Severity {
	p := new(EmitIssue_Severity)
	*p = x
	return p
}

func (x EmitIssue_Severity) String() string {
	return protoimpl.X.EnumStringOf(x.Descriptor(), protoreflect.EnumNumber(x))
}

func (EmitIssue_Severity) Descriptor() protoreflect.EnumDescriptor {
	return file_tflint_proto_enumTypes[4].Descriptor()
}

func (EmitIssue_Severity) Type() protoreflect.EnumType {
	return &file_tflint_proto_enumTypes[4]
}

func (x EmitIssue_Severity) Number() protoreflect.EnumNumber {
	return protoreflect.EnumNumber(x)
}

// Deprecated: Use EmitIssue_Severity.Descriptor instead.
func (EmitIssue_Severity) EnumDescriptor() ([]byte, []int) {
	return file_tflint_proto_rawDescGZIP(), []int{16, 0}
}

type GetName struct {
	state         protoimpl.MessageState `protogen:"open.v1"`
	unknownFields protoimpl.UnknownFields
	sizeCache     protoimpl.SizeCache
}

func (x *GetName) Reset() {
	*x = GetName{}
	mi := &file_tflint_proto_msgTypes[0]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *GetName) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*GetName) ProtoMessage() {}

func (x *GetName) ProtoReflect() protoreflect.Message {
	mi := &file_tflint_proto_msgTypes[0]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use GetName.ProtoReflect.Descriptor instead.
func (*GetName) Descriptor() ([]byte, []int) {
	return file_tflint_proto_rawDescGZIP(), []int{0}
}

type GetVersion struct {
	state         protoimpl.MessageState `protogen:"open.v1"`
	unknownFields protoimpl.UnknownFields
	sizeCache     protoimpl.SizeCache
}

func (x *GetVersion) Reset() {
	*x = GetVersion{}
	mi := &file_tflint_proto_msgTypes[1]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *GetVersion) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*GetVersion) ProtoMessage() {}

func (x *GetVersion) ProtoReflect() protoreflect.Message {
	mi := &file_tflint_proto_msgTypes[1]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use GetVersion.ProtoReflect.Descriptor instead.
func (*GetVersion) Descriptor() ([]byte, []int) {
	return file_tflint_proto_rawDescGZIP(), []int{1}
}

type GetVersionConstraint struct {
	state         protoimpl.MessageState `protogen:"open.v1"`
	unknownFields protoimpl.UnknownFields
	sizeCache     protoimpl.SizeCache
}

func (x *GetVersionConstraint) Reset() {
	*x = GetVersionConstraint{}
	mi := &file_tflint_proto_msgTypes[2]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *GetVersionConstraint) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*GetVersionConstraint) ProtoMessage() {}

func (x *GetVersionConstraint) ProtoReflect() protoreflect.Message {
	mi := &file_tflint_proto_msgTypes[2]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use GetVersionConstraint.ProtoReflect.Descriptor instead.
func (*GetVersionConstraint) Descriptor() ([]byte, []int) {
	return file_tflint_proto_rawDescGZIP(), []int{2}
}

type GetSDKVersion struct {
	state         protoimpl.MessageState `protogen:"open.v1"`
	unknownFields protoimpl.UnknownFields
	sizeCache     protoimpl.SizeCache
}

func (x *GetSDKVersion) Reset() {
	*x = GetSDKVersion{}
	mi := &file_tflint_proto_msgTypes[3]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *GetSDKVersion) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*GetSDKVersion) ProtoMessage() {}

func (x *GetSDKVersion) ProtoReflect() protoreflect.Message {
	mi := &file_tflint_proto_msgTypes[3]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use GetSDKVersion.ProtoReflect.Descriptor instead.
func (*GetSDKVersion) Descriptor() ([]byte, []int) {
	return file_tflint_proto_rawDescGZIP(), []int{3}
}

type GetRuleNames struct {
	state         protoimpl.MessageState `protogen:"open.v1"`
	unknownFields protoimpl.UnknownFields
	sizeCache     protoimpl.SizeCache
}

func (x *GetRuleNames) Reset() {
	*x = GetRuleNames{}
	mi := &file_tflint_proto_msgTypes[4]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *GetRuleNames) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*GetRuleNames) ProtoMessage() {}

func (x *GetRuleNames) ProtoReflect() protoreflect.Message {
	mi := &file_tflint_proto_msgTypes[4]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use GetRuleNames.ProtoReflect.Descriptor instead.
func (*GetRuleNames) Descriptor() ([]byte, []int) {
	return file_tflint_proto_rawDescGZIP(), []int{4}
}

type GetConfigSchema struct {
	state         protoimpl.MessageState `protogen:"open.v1"`
	unknownFields protoimpl.UnknownFields
	sizeCache     protoimpl.SizeCache
}

func (x *GetConfigSchema) Reset() {
	*x = GetConfigSchema{}
	mi := &file_tflint_proto_msgTypes[5]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *GetConfigSchema) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*GetConfigSchema) ProtoMessage() {}

func (x *GetConfigSchema) ProtoReflect() protoreflect.Message {
	mi := &file_tflint_proto_msgTypes[5]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use GetConfigSchema.ProtoReflect.Descriptor instead.
func (*GetConfigSchema) Descriptor() ([]byte, []int) {
	return file_tflint_proto_rawDescGZIP(), []int{5}
}

type ApplyGlobalConfig struct {
	state         protoimpl.MessageState `protogen:"open.v1"`
	unknownFields protoimpl.UnknownFields
	sizeCache     protoimpl.SizeCache
}

func (x *ApplyGlobalConfig) Reset() {
	*x = ApplyGlobalConfig{}
	mi := &file_tflint_proto_msgTypes[6]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *ApplyGlobalConfig) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*ApplyGlobalConfig) ProtoMessage() {}

func (x *ApplyGlobalConfig) ProtoReflect() protoreflect.Message {
	mi := &file_tflint_proto_msgTypes[6]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use ApplyGlobalConfig.ProtoReflect.Descriptor instead.
func (*ApplyGlobalConfig) Descriptor() ([]byte, []int) {
	return file_tflint_proto_rawDescGZIP(), []int{6}
}

type ApplyConfig struct {
	state         protoimpl.MessageState `protogen:"open.v1"`
	unknownFields protoimpl.UnknownFields
	sizeCache     protoimpl.SizeCache
}

func (x *ApplyConfig) Reset() {
	*x = ApplyConfig{}
	mi := &file_tflint_proto_msgTypes[7]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *ApplyConfig) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*ApplyConfig) ProtoMessage() {}

func (x *ApplyConfig) ProtoReflect() protoreflect.Message {
	mi := &file_tflint_proto_msgTypes[7]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use ApplyConfig.ProtoReflect.Descriptor instead.
func (*ApplyConfig) Descriptor() ([]byte, []int) {
	return file_tflint_proto_rawDescGZIP(), []int{7}
}

type Check struct {
	state         protoimpl.MessageState `protogen:"open.v1"`
	unknownFields protoimpl.UnknownFields
	sizeCache     protoimpl.SizeCache
}

func (x *Check) Reset() {
	*x = Check{}
	mi := &file_tflint_proto_msgTypes[8]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *Check) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*Check) ProtoMessage() {}

func (x *Check) ProtoReflect() protoreflect.Message {
	mi := &file_tflint_proto_msgTypes[8]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use Check.ProtoReflect.Descriptor instead.
func (*Check) Descriptor() ([]byte, []int) {
	return file_tflint_proto_rawDescGZIP(), []int{8}
}

type GetOriginalwd struct {
	state         protoimpl.MessageState `protogen:"open.v1"`
	unknownFields protoimpl.UnknownFields
	sizeCache     protoimpl.SizeCache
}

func (x *GetOriginalwd) Reset() {
	*x = GetOriginalwd{}
	mi := &file_tflint_proto_msgTypes[9]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *GetOriginalwd) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*GetOriginalwd) ProtoMessage() {}

func (x *GetOriginalwd) ProtoReflect() protoreflect.Message {
	mi := &file_tflint_proto_msgTypes[9]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use GetOriginalwd.ProtoReflect.Descriptor instead.
func (*GetOriginalwd) Descriptor() ([]byte, []int) {
	return file_tflint_proto_rawDescGZIP(), []int{9}
}

type GetModulePath struct {
	state         protoimpl.MessageState `protogen:"open.v1"`
	unknownFields protoimpl.UnknownFields
	sizeCache     protoimpl.SizeCache
}

func (x *GetModulePath) Reset() {
	*x = GetModulePath{}
	mi := &file_tflint_proto_msgTypes[10]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *GetModulePath) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*GetModulePath) ProtoMessage() {}

func (x *GetModulePath) ProtoReflect() protoreflect.Message {
	mi := &file_tflint_proto_msgTypes[10]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use GetModulePath.ProtoReflect.Descriptor instead.
func (*GetModulePath) Descriptor() ([]byte, []int) {
	return file_tflint_proto_rawDescGZIP(), []int{10}
}

type GetModuleContent struct {
	state         protoimpl.MessageState `protogen:"open.v1"`
	unknownFields protoimpl.UnknownFields
	sizeCache     protoimpl.SizeCache
}

func (x *GetModuleContent) Reset() {
	*x = GetModuleContent{}
	mi := &file_tflint_proto_msgTypes[11]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *GetModuleContent) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*GetModuleContent) ProtoMessage() {}

func (x *GetModuleContent) ProtoReflect() protoreflect.Message {
	mi := &file_tflint_proto_msgTypes[11]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use GetModuleContent.ProtoReflect.Descriptor instead.
func (*GetModuleContent) Descriptor() ([]byte, []int) {
	return file_tflint_proto_rawDescGZIP(), []int{11}
}

type GetFile struct {
	state         protoimpl.MessageState `protogen:"open.v1"`
	unknownFields protoimpl.UnknownFields
	sizeCache     protoimpl.SizeCache
}

func (x *GetFile) Reset() {
	*x = GetFile{}
	mi := &file_tflint_proto_msgTypes[12]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *GetFile) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*GetFile) ProtoMessage() {}

func (x *GetFile) ProtoReflect() protoreflect.Message {
	mi := &file_tflint_proto_msgTypes[12]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use GetFile.ProtoReflect.Descriptor instead.
func (*GetFile) Descriptor() ([]byte, []int) {
	return file_tflint_proto_rawDescGZIP(), []int{12}
}

type GetFiles struct {
	state         protoimpl.MessageState `protogen:"open.v1"`
	unknownFields protoimpl.UnknownFields
	sizeCache     protoimpl.SizeCache
}

func (x *GetFiles) Reset() {
	*x = GetFiles{}
	mi := &file_tflint_proto_msgTypes[13]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *GetFiles) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*GetFiles) ProtoMessage() {}

func (x *GetFiles) ProtoReflect() protoreflect.Message {
	mi := &file_tflint_proto_msgTypes[13]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use GetFiles.ProtoReflect.Descriptor instead.
func (*GetFiles) Descriptor() ([]byte, []int) {
	return file_tflint_proto_rawDescGZIP(), []int{13}
}

type GetRuleConfigContent struct {
	state         protoimpl.MessageState `protogen:"open.v1"`
	unknownFields protoimpl.UnknownFields
	sizeCache     protoimpl.SizeCache
}

func (x *GetRuleConfigContent) Reset() {
	*x = GetRuleConfigContent{}
	mi := &file_tflint_proto_msgTypes[14]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *GetRuleConfigContent) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*GetRuleConfigContent) ProtoMessage() {}

func (x *GetRuleConfigContent) ProtoReflect() protoreflect.Message {
	mi := &file_tflint_proto_msgTypes[14]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use GetRuleConfigContent.ProtoReflect.Descriptor instead.
func (*GetRuleConfigContent) Descriptor() ([]byte, []int) {
	return file_tflint_proto_rawDescGZIP(), []int{14}
}

type EvaluateExpr struct {
	state         protoimpl.MessageState `protogen:"open.v1"`
	unknownFields protoimpl.UnknownFields
	sizeCache     protoimpl.SizeCache
}

func (x *EvaluateExpr) Reset() {
	*x = EvaluateExpr{}
	mi := &file_tflint_proto_msgTypes[15]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *EvaluateExpr) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*EvaluateExpr) ProtoMessage() {}

func (x *EvaluateExpr) ProtoReflect() protoreflect.Message {
	mi := &file_tflint_proto_msgTypes[15]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use EvaluateExpr.ProtoReflect.Descriptor instead.
func (*EvaluateExpr) Descriptor() ([]byte, []int) {
	return file_tflint_proto_rawDescGZIP(), []int{15}
}

type EmitIssue struct {
	state         protoimpl.MessageState `protogen:"open.v1"`
	unknownFields protoimpl.UnknownFields
	sizeCache     protoimpl.SizeCache
}

func (x *EmitIssue) Reset() {
	*x = EmitIssue{}
	mi := &file_tflint_proto_msgTypes[16]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *EmitIssue) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*EmitIssue) ProtoMessage() {}

func (x *EmitIssue) ProtoReflect() protoreflect.Message {
	mi := &file_tflint_proto_msgTypes[16]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use EmitIssue.ProtoReflect.Descriptor instead.
func (*EmitIssue) Descriptor() ([]byte, []int) {
	return file_tflint_proto_rawDescGZIP(), []int{16}
}

type ApplyChanges struct {
	state         protoimpl.MessageState `protogen:"open.v1"`
	unknownFields protoimpl.UnknownFields
	sizeCache     protoimpl.SizeCache
}

func (x *ApplyChanges) Reset() {
	*x = ApplyChanges{}
	mi := &file_tflint_proto_msgTypes[17]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *ApplyChanges) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*ApplyChanges) ProtoMessage() {}

func (x *ApplyChanges) ProtoReflect() protoreflect.Message {
	mi := &file_tflint_proto_msgTypes[17]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use ApplyChanges.ProtoReflect.Descriptor instead.
func (*ApplyChanges) Descriptor() ([]byte, []int) {
	return file_tflint_proto_rawDescGZIP(), []int{17}
}

type BodySchema struct {
	state         protoimpl.MessageState  `protogen:"open.v1"`
	Attributes    []*BodySchema_Attribute `protobuf:"bytes,1,rep,name=attributes,proto3" json:"attributes,omitempty"`
	Blocks        []*BodySchema_Block     `protobuf:"bytes,2,rep,name=blocks,proto3" json:"blocks,omitempty"`
	Mode          SchemaMode              `protobuf:"varint,3,opt,name=Mode,proto3,enum=proto.SchemaMode" json:"Mode,omitempty"`
	unknownFields protoimpl.UnknownFields
	sizeCache     protoimpl.SizeCache
}

func (x *BodySchema) Reset() {
	*x = BodySchema{}
	mi := &file_tflint_proto_msgTypes[18]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *BodySchema) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*BodySchema) ProtoMessage() {}

func (x *BodySchema) ProtoReflect() protoreflect.Message {
	mi := &file_tflint_proto_msgTypes[18]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use BodySchema.ProtoReflect.Descriptor instead.
func (*BodySchema) Descriptor() ([]byte, []int) {
	return file_tflint_proto_rawDescGZIP(), []int{18}
}

func (x *BodySchema) GetAttributes() []*BodySchema_Attribute {
	if x != nil {
		return x.Attributes
	}
	return nil
}

func (x *BodySchema) GetBlocks() []*BodySchema_Block {
	if x != nil {
		return x.Blocks
	}
	return nil
}

func (x *BodySchema) GetMode() SchemaMode {
	if x != nil {
		return x.Mode
	}
	return SchemaMode_SCHEMA_MODE_UNSPECIFIED
}

type BodyContent struct {
	state         protoimpl.MessageState            `protogen:"open.v1"`
	Attributes    map[string]*BodyContent_Attribute `protobuf:"bytes,1,rep,name=attributes,proto3" json:"attributes,omitempty" protobuf_key:"bytes,1,opt,name=key" protobuf_val:"bytes,2,opt,name=value"`
	Blocks        []*BodyContent_Block              `protobuf:"bytes,2,rep,name=blocks,proto3" json:"blocks,omitempty"`
	unknownFields protoimpl.UnknownFields
	sizeCache     protoimpl.SizeCache
}

func (x *BodyContent) Reset() {
	*x = BodyContent{}
	mi := &file_tflint_proto_msgTypes[19]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *BodyContent) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*BodyContent) ProtoMessage() {}

func (x *BodyContent) ProtoReflect() protoreflect.Message {
	mi := &file_tflint_proto_msgTypes[19]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use BodyContent.ProtoReflect.Descriptor instead.
func (*BodyContent) Descriptor() ([]byte, []int) {
	return file_tflint_proto_rawDescGZIP(), []int{19}
}

func (x *BodyContent) GetAttributes() map[string]*BodyContent_Attribute {
	if x != nil {
		return x.Attributes
	}
	return nil
}

func (x *BodyContent) GetBlocks() []*BodyContent_Block {
	if x != nil {
		return x.Blocks
	}
	return nil
}

type Expression struct {
	state         protoimpl.MessageState `protogen:"open.v1"`
	Bytes         []byte                 `protobuf:"bytes,1,opt,name=bytes,proto3" json:"bytes,omitempty"`
	Range         *Range                 `protobuf:"bytes,2,opt,name=range,proto3" json:"range,omitempty"`
	Value         []byte                 `protobuf:"bytes,3,opt,name=value,proto3" json:"value,omitempty"`
	ValueMarks    []*ValueMark           `protobuf:"bytes,4,rep,name=value_marks,json=valueMarks,proto3" json:"value_marks,omitempty"`
	unknownFields protoimpl.UnknownFields
	sizeCache     protoimpl.SizeCache
}

func (x *Expression) Reset() {
	*x = Expression{}
	mi := &file_tflint_proto_msgTypes[20]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *Expression) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*Expression) ProtoMessage() {}

func (x *Expression) ProtoReflect() protoreflect.Message {
	mi := &file_tflint_proto_msgTypes[20]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use Expression.ProtoReflect.Descriptor instead.
func (*Expression) Descriptor() ([]byte, []int) {
	return file_tflint_proto_rawDescGZIP(), []int{20}
}

func (x *Expression) GetBytes() []byte {
	if x != nil {
		return x.Bytes
	}
	return nil
}

func (x *Expression) GetRange() *Range {
	if x != nil {
		return x.Range
	}
	return nil
}

func (x *Expression) GetValue() []byte {
	if x != nil {
		return x.Value
	}
	return nil
}

func (x *Expression) GetValueMarks() []*ValueMark {
	if x != nil {
		return x.ValueMarks
	}
	return nil
}

type Range struct {
	state         protoimpl.MessageState `protogen:"open.v1"`
	Filename      string                 `protobuf:"bytes,1,opt,name=filename,proto3" json:"filename,omitempty"`
	Start         *Range_Pos             `protobuf:"bytes,2,opt,name=start,proto3" json:"start,omitempty"`
	End           *Range_Pos             `protobuf:"bytes,3,opt,name=end,proto3" json:"end,omitempty"`
	unknownFields protoimpl.UnknownFields
	sizeCache     protoimpl.SizeCache
}

func (x *Range) Reset() {
	*x = Range{}
	mi := &file_tflint_proto_msgTypes[21]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *Range) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*Range) ProtoMessage() {}

func (x *Range) ProtoReflect() protoreflect.Message {
	mi := &file_tflint_proto_msgTypes[21]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use Range.ProtoReflect.Descriptor instead.
func (*Range) Descriptor() ([]byte, []int) {
	return file_tflint_proto_rawDescGZIP(), []int{21}
}

func (x *Range) GetFilename() string {
	if x != nil {
		return x.Filename
	}
	return ""
}

func (x *Range) GetStart() *Range_Pos {
	if x != nil {
		return x.Start
	}
	return nil
}

func (x *Range) GetEnd() *Range_Pos {
	if x != nil {
		return x.End
	}
	return nil
}

type AttributePath struct {
	state         protoimpl.MessageState `protogen:"open.v1"`
	Steps         []*AttributePath_Step  `protobuf:"bytes,1,rep,name=steps,proto3" json:"steps,omitempty"`
	unknownFields protoimpl.UnknownFields
	sizeCache     protoimpl.SizeCache
}

func (x *AttributePath) Reset() {
	*x = AttributePath{}
	mi := &file_tflint_proto_msgTypes[22]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *AttributePath) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*AttributePath) ProtoMessage() {}

func (x *AttributePath) ProtoReflect() protoreflect.Message {
	mi := &file_tflint_proto_msgTypes[22]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use AttributePath.ProtoReflect.Descriptor instead.
func (*AttributePath) Descriptor() ([]byte, []int) {
	return file_tflint_proto_rawDescGZIP(), []int{22}
}

func (x *AttributePath) GetSteps() []*AttributePath_Step {
	if x != nil {
		return x.Steps
	}
	return nil
}

type ValueMark struct {
	state         protoimpl.MessageState `protogen:"open.v1"`
	Path          *AttributePath         `protobuf:"bytes,1,opt,name=path,proto3" json:"path,omitempty"`
	Sensitive     bool                   `protobuf:"varint,2,opt,name=sensitive,proto3" json:"sensitive,omitempty"`
	Ephemeral     bool                   `protobuf:"varint,3,opt,name=ephemeral,proto3" json:"ephemeral,omitempty"`
	unknownFields protoimpl.UnknownFields
	sizeCache     protoimpl.SizeCache
}

func (x *ValueMark) Reset() {
	*x = ValueMark{}
	mi := &file_tflint_proto_msgTypes[23]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *ValueMark) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*ValueMark) ProtoMessage() {}

func (x *ValueMark) ProtoReflect() protoreflect.Message {
	mi := &file_tflint_proto_msgTypes[23]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use ValueMark.ProtoReflect.Descriptor instead.
func (*ValueMark) Descriptor() ([]byte, []int) {
	return file_tflint_proto_rawDescGZIP(), []int{23}
}

func (x *ValueMark) GetPath() *AttributePath {
	if x != nil {
		return x.Path
	}
	return nil
}

func (x *ValueMark) GetSensitive() bool {
	if x != nil {
		return x.Sensitive
	}
	return false
}

func (x *ValueMark) GetEphemeral() bool {
	if x != nil {
		return x.Ephemeral
	}
	return false
}

type ErrorDetail struct {
	state         protoimpl.MessageState `protogen:"open.v1"`
	Code          ErrorCode              `protobuf:"varint,1,opt,name=code,proto3,enum=proto.ErrorCode" json:"code,omitempty"`
	Message       string                 `protobuf:"bytes,2,opt,name=message,proto3" json:"message,omitempty"`
	unknownFields protoimpl.UnknownFields
	sizeCache     protoimpl.SizeCache
}

func (x *ErrorDetail) Reset() {
	*x = ErrorDetail{}
	mi := &file_tflint_proto_msgTypes[24]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *ErrorDetail) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*ErrorDetail) ProtoMessage() {}

func (x *ErrorDetail) ProtoReflect() protoreflect.Message {
	mi := &file_tflint_proto_msgTypes[24]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use ErrorDetail.ProtoReflect.Descriptor instead.
func (*ErrorDetail) Descriptor() ([]byte, []int) {
	return file_tflint_proto_rawDescGZIP(), []int{24}
}

func (x *ErrorDetail) GetCode() ErrorCode {
	if x != nil {
		return x.Code
	}
	return ErrorCode_ERROR_CODE_UNSPECIFIED
}

func (x *ErrorDetail) GetMessage() string {
	if x != nil {
		return x.Message
	}
	return ""
}

type GetName_Request struct {
	state         protoimpl.MessageState `protogen:"open.v1"`
	unknownFields protoimpl.UnknownFields
	sizeCache     protoimpl.SizeCache
}

func (x *GetName_Request) Reset() {
	*x = GetName_Request{}
	mi := &file_tflint_proto_msgTypes[25]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *GetName_Request) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*GetName_Request) ProtoMessage() {}

func (x *GetName_Request) ProtoReflect() protoreflect.Message {
	mi := &file_tflint_proto_msgTypes[25]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use GetName_Request.ProtoReflect.Descriptor instead.
func (*GetName_Request) Descriptor() ([]byte, []int) {
	return file_tflint_proto_rawDescGZIP(), []int{0, 0}
}

type GetName_Response struct {
	state         protoimpl.MessageState `protogen:"open.v1"`
	Name          string                 `protobuf:"bytes,1,opt,name=name,proto3" json:"name,omitempty"`
	unknownFields protoimpl.UnknownFields
	sizeCache     protoimpl.SizeCache
}

func (x *GetName_Response) Reset() {
	*x = GetName_Response{}
	mi := &file_tflint_proto_msgTypes[26]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *GetName_Response) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*GetName_Response) ProtoMessage() {}

func (x *GetName_Response) ProtoReflect() protoreflect.Message {
	mi := &file_tflint_proto_msgTypes[26]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use GetName_Response.ProtoReflect.Descriptor instead.
func (*GetName_Response) Descriptor() ([]byte, []int) {
	return file_tflint_proto_rawDescGZIP(), []int{0, 1}
}

func (x *GetName_Response) GetName() string {
	if x != nil {
		return x.Name
	}
	return ""
}

type GetVersion_Request struct {
	state         protoimpl.MessageState `protogen:"open.v1"`
	unknownFields protoimpl.UnknownFields
	sizeCache     protoimpl.SizeCache
}

func (x *GetVersion_Request) Reset() {
	*x = GetVersion_Request{}
	mi := &file_tflint_proto_msgTypes[27]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *GetVersion_Request) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*GetVersion_Request) ProtoMessage() {}

func (x *GetVersion_Request) ProtoReflect() protoreflect.Message {
	mi := &file_tflint_proto_msgTypes[27]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use GetVersion_Request.ProtoReflect.Descriptor instead.
func (*GetVersion_Request) Descriptor() ([]byte, []int) {
	return file_tflint_proto_rawDescGZIP(), []int{1, 0}
}

type GetVersion_Response struct {
	state         protoimpl.MessageState `protogen:"open.v1"`
	Version       string                 `protobuf:"bytes,1,opt,name=version,proto3" json:"version,omitempty"`
	unknownFields protoimpl.UnknownFields
	sizeCache     protoimpl.SizeCache
}

func (x *GetVersion_Response) Reset() {
	*x = GetVersion_Response{}
	mi := &file_tflint_proto_msgTypes[28]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *GetVersion_Response) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*GetVersion_Response) ProtoMessage() {}

func (x *GetVersion_Response) ProtoReflect() protoreflect.Message {
	mi := &file_tflint_proto_msgTypes[28]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use GetVersion_Response.ProtoReflect.Descriptor instead.
func (*GetVersion_Response) Descriptor() ([]byte, []int) {
	return file_tflint_proto_rawDescGZIP(), []int{1, 1}
}

func (x *GetVersion_Response) GetVersion() string {
	if x != nil {
		return x.Version
	}
	return ""
}

type GetVersionConstraint_Request struct {
	state         protoimpl.MessageState `protogen:"open.v1"`
	unknownFields protoimpl.UnknownFields
	sizeCache     protoimpl.SizeCache
}

func (x *GetVersionConstraint_Request) Reset() {
	*x = GetVersionConstraint_Request{}
	mi := &file_tflint_proto_msgTypes[29]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *GetVersionConstraint_Request) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*GetVersionConstraint_Request) ProtoMessage() {}

func (x *GetVersionConstraint_Request) ProtoReflect() protoreflect.Message {
	mi := &file_tflint_proto_msgTypes[29]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use GetVersionConstraint_Request.ProtoReflect.Descriptor instead.
func (*GetVersionConstraint_Request) Descriptor() ([]byte, []int) {
	return file_tflint_proto_rawDescGZIP(), []int{2, 0}
}

type GetVersionConstraint_Response struct {
	state         protoimpl.MessageState `protogen:"open.v1"`
	Constraint    string                 `protobuf:"bytes,1,opt,name=constraint,proto3" json:"constraint,omitempty"`
	unknownFields protoimpl.UnknownFields
	sizeCache     protoimpl.SizeCache
}

func (x *GetVersionConstraint_Response) Reset() {
	*x = GetVersionConstraint_Response{}
	mi := &file_tflint_proto_msgTypes[30]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *GetVersionConstraint_Response) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*GetVersionConstraint_Response) ProtoMessage() {}

func (x *GetVersionConstraint_Response) ProtoReflect() protoreflect.Message {
	mi := &file_tflint_proto_msgTypes[30]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use GetVersionConstraint_Response.ProtoReflect.Descriptor instead.
func (*GetVersionConstraint_Response) Descriptor() ([]byte, []int) {
	return file_tflint_proto_rawDescGZIP(), []int{2, 1}
}

func (x *GetVersionConstraint_Response) GetConstraint() string {
	if x != nil {
		return x.Constraint
	}
	return ""
}

type GetSDKVersion_Request struct {
	state         protoimpl.MessageState `protogen:"open.v1"`
	unknownFields protoimpl.UnknownFields
	sizeCache     protoimpl.SizeCache
}

func (x *GetSDKVersion_Request) Reset() {
	*x = GetSDKVersion_Request{}
	mi := &file_tflint_proto_msgTypes[31]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *GetSDKVersion_Request) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*GetSDKVersion_Request) ProtoMessage() {}

func (x *GetSDKVersion_Request) ProtoReflect() protoreflect.Message {
	mi := &file_tflint_proto_msgTypes[31]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use GetSDKVersion_Request.ProtoReflect.Descriptor instead.
func (*GetSDKVersion_Request) Descriptor() ([]byte, []int) {
	return file_tflint_proto_rawDescGZIP(), []int{3, 0}
}

type GetSDKVersion_Response struct {
	state         protoimpl.MessageState `protogen:"open.v1"`
	Version       string                 `protobuf:"bytes,1,opt,name=version,proto3" json:"version,omitempty"`
	unknownFields protoimpl.UnknownFields
	sizeCache     protoimpl.SizeCache
}

func (x *GetSDKVersion_Response) Reset() {
	*x = GetSDKVersion_Response{}
	mi := &file_tflint_proto_msgTypes[32]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *GetSDKVersion_Response) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*GetSDKVersion_Response) ProtoMessage() {}

func (x *GetSDKVersion_Response) ProtoReflect() protoreflect.Message {
	mi := &file_tflint_proto_msgTypes[32]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use GetSDKVersion_Response.ProtoReflect.Descriptor instead.
func (*GetSDKVersion_Response) Descriptor() ([]byte, []int) {
	return file_tflint_proto_rawDescGZIP(), []int{3, 1}
}

func (x *GetSDKVersion_Response) GetVersion() string {
	if x != nil {
		return x.Version
	}
	return ""
}

type GetRuleNames_Request struct {
	state         protoimpl.MessageState `protogen:"open.v1"`
	unknownFields protoimpl.UnknownFields
	sizeCache     protoimpl.SizeCache
}

func (x *GetRuleNames_Request) Reset() {
	*x = GetRuleNames_Request{}
	mi := &file_tflint_proto_msgTypes[33]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *GetRuleNames_Request) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*GetRuleNames_Request) ProtoMessage() {}

func (x *GetRuleNames_Request) ProtoReflect() protoreflect.Message {
	mi := &file_tflint_proto_msgTypes[33]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use GetRuleNames_Request.ProtoReflect.Descriptor instead.
func (*GetRuleNames_Request) Descriptor() ([]byte, []int) {
	return file_tflint_proto_rawDescGZIP(), []int{4, 0}
}

type GetRuleNames_Response struct {
	state         protoimpl.MessageState `protogen:"open.v1"`
	Names         []string               `protobuf:"bytes,1,rep,name=names,proto3" json:"names,omitempty"`
	unknownFields protoimpl.UnknownFields
	sizeCache     protoimpl.SizeCache
}

func (x *GetRuleNames_Response) Reset() {
	*x = GetRuleNames_Response{}
	mi := &file_tflint_proto_msgTypes[34]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *GetRuleNames_Response) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*GetRuleNames_Response) ProtoMessage() {}

func (x *GetRuleNames_Response) ProtoReflect() protoreflect.Message {
	mi := &file_tflint_proto_msgTypes[34]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use GetRuleNames_Response.ProtoReflect.Descriptor instead.
func (*GetRuleNames_Response) Descriptor() ([]byte, []int) {
	return file_tflint_proto_rawDescGZIP(), []int{4, 1}
}

func (x *GetRuleNames_Response) GetNames() []string {
	if x != nil {
		return x.Names
	}
	return nil
}

type GetConfigSchema_Request struct {
	state         protoimpl.MessageState `protogen:"open.v1"`
	unknownFields protoimpl.UnknownFields
	sizeCache     protoimpl.SizeCache
}

func (x *GetConfigSchema_Request) Reset() {
	*x = GetConfigSchema_Request{}
	mi := &file_tflint_proto_msgTypes[35]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *GetConfigSchema_Request) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*GetConfigSchema_Request) ProtoMessage() {}

func (x *GetConfigSchema_Request) ProtoReflect() protoreflect.Message {
	mi := &file_tflint_proto_msgTypes[35]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use GetConfigSchema_Request.ProtoReflect.Descriptor instead.
func (*GetConfigSchema_Request) Descriptor() ([]byte, []int) {
	return file_tflint_proto_rawDescGZIP(), []int{5, 0}
}

type GetConfigSchema_Response struct {
	state         protoimpl.MessageState `protogen:"open.v1"`
	Schema        *BodySchema            `protobuf:"bytes,1,opt,name=schema,proto3" json:"schema,omitempty"`
	unknownFields protoimpl.UnknownFields
	sizeCache     protoimpl.SizeCache
}

func (x *GetConfigSchema_Response) Reset() {
	*x = GetConfigSchema_Response{}
	mi := &file_tflint_proto_msgTypes[36]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *GetConfigSchema_Response) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*GetConfigSchema_Response) ProtoMessage() {}

func (x *GetConfigSchema_Response) ProtoReflect() protoreflect.Message {
	mi := &file_tflint_proto_msgTypes[36]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use GetConfigSchema_Response.ProtoReflect.Descriptor instead.
func (*GetConfigSchema_Response) Descriptor() ([]byte, []int) {
	return file_tflint_proto_rawDescGZIP(), []int{5, 1}
}

func (x *GetConfigSchema_Response) GetSchema() *BodySchema {
	if x != nil {
		return x.Schema
	}
	return nil
}

type ApplyGlobalConfig_Config struct {
	state             protoimpl.MessageState                   `protogen:"open.v1"`
	Rules             map[string]*ApplyGlobalConfig_RuleConfig `protobuf:"bytes,1,rep,name=rules,proto3" json:"rules,omitempty" protobuf_key:"bytes,1,opt,name=key" protobuf_val:"bytes,2,opt,name=value"`
	DisabledByDefault bool                                     `protobuf:"varint,2,opt,name=disabled_by_default,json=disabledByDefault,proto3" json:"disabled_by_default,omitempty"`
	Only              []string                                 `protobuf:"bytes,3,rep,name=only,proto3" json:"only,omitempty"`
	Fix               bool                                     `protobuf:"varint,4,opt,name=fix,proto3" json:"fix,omitempty"`
	unknownFields     protoimpl.UnknownFields
	sizeCache         protoimpl.SizeCache
}

func (x *ApplyGlobalConfig_Config) Reset() {
	*x = ApplyGlobalConfig_Config{}
	mi := &file_tflint_proto_msgTypes[37]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *ApplyGlobalConfig_Config) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*ApplyGlobalConfig_Config) ProtoMessage() {}

func (x *ApplyGlobalConfig_Config) ProtoReflect() protoreflect.Message {
	mi := &file_tflint_proto_msgTypes[37]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use ApplyGlobalConfig_Config.ProtoReflect.Descriptor instead.
func (*ApplyGlobalConfig_Config) Descriptor() ([]byte, []int) {
	return file_tflint_proto_rawDescGZIP(), []int{6, 0}
}

func (x *ApplyGlobalConfig_Config) GetRules() map[string]*ApplyGlobalConfig_RuleConfig {
	if x != nil {
		return x.Rules
	}
	return nil
}

func (x *ApplyGlobalConfig_Config) GetDisabledByDefault() bool {
	if x != nil {
		return x.DisabledByDefault
	}
	return false
}

func (x *ApplyGlobalConfig_Config) GetOnly() []string {
	if x != nil {
		return x.Only
	}
	return nil
}

func (x *ApplyGlobalConfig_Config) GetFix() bool {
	if x != nil {
		return x.Fix
	}
	return false
}

type ApplyGlobalConfig_RuleConfig struct {
	state         protoimpl.MessageState `protogen:"open.v1"`
	Name          string                 `protobuf:"bytes,1,opt,name=name,proto3" json:"name,omitempty"`
	Enabled       bool                   `protobuf:"varint,2,opt,name=enabled,proto3" json:"enabled,omitempty"`
	unknownFields protoimpl.UnknownFields
	sizeCache     protoimpl.SizeCache
}

func (x *ApplyGlobalConfig_RuleConfig) Reset() {
	*x = ApplyGlobalConfig_RuleConfig{}
	mi := &file_tflint_proto_msgTypes[38]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *ApplyGlobalConfig_RuleConfig) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*ApplyGlobalConfig_RuleConfig) ProtoMessage() {}

func (x *ApplyGlobalConfig_RuleConfig) ProtoReflect() protoreflect.Message {
	mi := &file_tflint_proto_msgTypes[38]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use ApplyGlobalConfig_RuleConfig.ProtoReflect.Descriptor instead.
func (*ApplyGlobalConfig_RuleConfig) Descriptor() ([]byte, []int) {
	return file_tflint_proto_rawDescGZIP(), []int{6, 1}
}

func (x *ApplyGlobalConfig_RuleConfig) GetName() string {
	if x != nil {
		return x.Name
	}
	return ""
}

func (x *ApplyGlobalConfig_RuleConfig) GetEnabled() bool {
	if x != nil {
		return x.Enabled
	}
	return false
}

type ApplyGlobalConfig_Request struct {
	state         protoimpl.MessageState    `protogen:"open.v1"`
	Config        *ApplyGlobalConfig_Config `protobuf:"bytes,1,opt,name=config,proto3" json:"config,omitempty"`
	unknownFields protoimpl.UnknownFields
	sizeCache     protoimpl.SizeCache
}

func (x *ApplyGlobalConfig_Request) Reset() {
	*x = ApplyGlobalConfig_Request{}
	mi := &file_tflint_proto_msgTypes[39]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *ApplyGlobalConfig_Request) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*ApplyGlobalConfig_Request) ProtoMessage() {}

func (x *ApplyGlobalConfig_Request) ProtoReflect() protoreflect.Message {
	mi := &file_tflint_proto_msgTypes[39]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use ApplyGlobalConfig_Request.ProtoReflect.Descriptor instead.
func (*ApplyGlobalConfig_Request) Descriptor() ([]byte, []int) {
	return file_tflint_proto_rawDescGZIP(), []int{6, 2}
}

func (x *ApplyGlobalConfig_Request) GetConfig() *ApplyGlobalConfig_Config {
	if x != nil {
		return x.Config
	}
	return nil
}

type ApplyGlobalConfig_Response struct {
	state         protoimpl.MessageState `protogen:"open.v1"`
	unknownFields protoimpl.UnknownFields
	sizeCache     protoimpl.SizeCache
}

func (x *ApplyGlobalConfig_Response) Reset() {
	*x = ApplyGlobalConfig_Response{}
	mi := &file_tflint_proto_msgTypes[40]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *ApplyGlobalConfig_Response) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*ApplyGlobalConfig_Response) ProtoMessage() {}

func (x *ApplyGlobalConfig_Response) ProtoReflect() protoreflect.Message {
	mi := &file_tflint_proto_msgTypes[40]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use ApplyGlobalConfig_Response.ProtoReflect.Descriptor instead.
func (*ApplyGlobalConfig_Response) Descriptor() ([]byte, []int) {
	return file_tflint_proto_rawDescGZIP(), []int{6, 3}
}

type ApplyConfig_Request struct {
	state         protoimpl.MessageState `protogen:"open.v1"`
	Content       *BodyContent           `protobuf:"bytes,1,opt,name=content,proto3" json:"content,omitempty"`
	unknownFields protoimpl.UnknownFields
	sizeCache     protoimpl.SizeCache
}

func (x *ApplyConfig_Request) Reset() {
	*x = ApplyConfig_Request{}
	mi := &file_tflint_proto_msgTypes[42]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *ApplyConfig_Request) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*ApplyConfig_Request) ProtoMessage() {}

func (x *ApplyConfig_Request) ProtoReflect() protoreflect.Message {
	mi := &file_tflint_proto_msgTypes[42]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use ApplyConfig_Request.ProtoReflect.Descriptor instead.
func (*ApplyConfig_Request) Descriptor() ([]byte, []int) {
	return file_tflint_proto_rawDescGZIP(), []int{7, 0}
}

func (x *ApplyConfig_Request) GetContent() *BodyContent {
	if x != nil {
		return x.Content
	}
	return nil
}

type ApplyConfig_Response struct {
	state         protoimpl.MessageState `protogen:"open.v1"`
	unknownFields protoimpl.UnknownFields
	sizeCache     protoimpl.SizeCache
}

func (x *ApplyConfig_Response) Reset() {
	*x = ApplyConfig_Response{}
	mi := &file_tflint_proto_msgTypes[43]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *ApplyConfig_Response) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*ApplyConfig_Response) ProtoMessage() {}

func (x *ApplyConfig_Response) ProtoReflect() protoreflect.Message {
	mi := &file_tflint_proto_msgTypes[43]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use ApplyConfig_Response.ProtoReflect.Descriptor instead.
func (*ApplyConfig_Response) Descriptor() ([]byte, []int) {
	return file_tflint_proto_rawDescGZIP(), []int{7, 1}
}

type Check_Request struct {
	state         protoimpl.MessageState `protogen:"open.v1"`
	Runner        uint32                 `protobuf:"varint,1,opt,name=runner,proto3" json:"runner,omitempty"`
	unknownFields protoimpl.UnknownFields
	sizeCache     protoimpl.SizeCache
}

func (x *Check_Request) Reset() {
	*x = Check_Request{}
	mi := &file_tflint_proto_msgTypes[44]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *Check_Request) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*Check_Request) ProtoMessage() {}

func (x *Check_Request) ProtoReflect() protoreflect.Message {
	mi := &file_tflint_proto_msgTypes[44]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use Check_Request.ProtoReflect.Descriptor instead.
func (*Check_Request) Descriptor() ([]byte, []int) {
	return file_tflint_proto_rawDescGZIP(), []int{8, 0}
}

func (x *Check_Request) GetRunner() uint32 {
	if x != nil {
		return x.Runner
	}
	return 0
}

type Check_Response struct {
	state         protoimpl.MessageState `protogen:"open.v1"`
	unknownFields protoimpl.UnknownFields
	sizeCache     protoimpl.SizeCache
}

func (x *Check_Response) Reset() {
	*x = Check_Response{}
	mi := &file_tflint_proto_msgTypes[45]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *Check_Response) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*Check_Response) ProtoMessage() {}

func (x *Check_Response) ProtoReflect() protoreflect.Message {
	mi := &file_tflint_proto_msgTypes[45]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use Check_Response.ProtoReflect.Descriptor instead.
func (*Check_Response) Descriptor() ([]byte, []int) {
	return file_tflint_proto_rawDescGZIP(), []int{8, 1}
}

type GetOriginalwd_Request struct {
	state         protoimpl.MessageState `protogen:"open.v1"`
	unknownFields protoimpl.UnknownFields
	sizeCache     protoimpl.SizeCache
}

func (x *GetOriginalwd_Request) Reset() {
	*x = GetOriginalwd_Request{}
	mi := &file_tflint_proto_msgTypes[46]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *GetOriginalwd_Request) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*GetOriginalwd_Request) ProtoMessage() {}

func (x *GetOriginalwd_Request) ProtoReflect() protoreflect.Message {
	mi := &file_tflint_proto_msgTypes[46]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use GetOriginalwd_Request.ProtoReflect.Descriptor instead.
func (*GetOriginalwd_Request) Descriptor() ([]byte, []int) {
	return file_tflint_proto_rawDescGZIP(), []int{9, 0}
}

type GetOriginalwd_Response struct {
	state         protoimpl.MessageState `protogen:"open.v1"`
	Path          string                 `protobuf:"bytes,1,opt,name=path,proto3" json:"path,omitempty"`
	unknownFields protoimpl.UnknownFields
	sizeCache     protoimpl.SizeCache
}

func (x *GetOriginalwd_Response) Reset() {
	*x = GetOriginalwd_Response{}
	mi := &file_tflint_proto_msgTypes[47]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *GetOriginalwd_Response) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*GetOriginalwd_Response) ProtoMessage() {}

func (x *GetOriginalwd_Response) ProtoReflect() protoreflect.Message {
	mi := &file_tflint_proto_msgTypes[47]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use GetOriginalwd_Response.ProtoReflect.Descriptor instead.
func (*GetOriginalwd_Response) Descriptor() ([]byte, []int) {
	return file_tflint_proto_rawDescGZIP(), []int{9, 1}
}

func (x *GetOriginalwd_Response) GetPath() string {
	if x != nil {
		return x.Path
	}
	return ""
}

type GetModulePath_Request struct {
	state         protoimpl.MessageState `protogen:"open.v1"`
	unknownFields protoimpl.UnknownFields
	sizeCache     protoimpl.SizeCache
}

func (x *GetModulePath_Request) Reset() {
	*x = GetModulePath_Request{}
	mi := &file_tflint_proto_msgTypes[48]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *GetModulePath_Request) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*GetModulePath_Request) ProtoMessage() {}

func (x *GetModulePath_Request) ProtoReflect() protoreflect.Message {
	mi := &file_tflint_proto_msgTypes[48]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use GetModulePath_Request.ProtoReflect.Descriptor instead.
func (*GetModulePath_Request) Descriptor() ([]byte, []int) {
	return file_tflint_proto_rawDescGZIP(), []int{10, 0}
}

type GetModulePath_Response struct {
	state         protoimpl.MessageState `protogen:"open.v1"`
	Path          []string               `protobuf:"bytes,1,rep,name=path,proto3" json:"path,omitempty"`
	unknownFields protoimpl.UnknownFields
	sizeCache     protoimpl.SizeCache
}

func (x *GetModulePath_Response) Reset() {
	*x = GetModulePath_Response{}
	mi := &file_tflint_proto_msgTypes[49]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *GetModulePath_Response) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*GetModulePath_Response) ProtoMessage() {}

func (x *GetModulePath_Response) ProtoReflect() protoreflect.Message {
	mi := &file_tflint_proto_msgTypes[49]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use GetModulePath_Response.ProtoReflect.Descriptor instead.
func (*GetModulePath_Response) Descriptor() ([]byte, []int) {
	return file_tflint_proto_rawDescGZIP(), []int{10, 1}
}

func (x *GetModulePath_Response) GetPath() []string {
	if x != nil {
		return x.Path
	}
	return nil
}

type GetModuleContent_Hint struct {
	state         protoimpl.MessageState `protogen:"open.v1"`
	ResourceType  string                 `protobuf:"bytes,1,opt,name=resource_type,json=resourceType,proto3" json:"resource_type,omitempty"`
	unknownFields protoimpl.UnknownFields
	sizeCache     protoimpl.SizeCache
}

func (x *GetModuleContent_Hint) Reset() {
	*x = GetModuleContent_Hint{}
	mi := &file_tflint_proto_msgTypes[50]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *GetModuleContent_Hint) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*GetModuleContent_Hint) ProtoMessage() {}

func (x *GetModuleContent_Hint) ProtoReflect() protoreflect.Message {
	mi := &file_tflint_proto_msgTypes[50]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use GetModuleContent_Hint.ProtoReflect.Descriptor instead.
func (*GetModuleContent_Hint) Descriptor() ([]byte, []int) {
	return file_tflint_proto_rawDescGZIP(), []int{11, 0}
}

func (x *GetModuleContent_Hint) GetResourceType() string {
	if x != nil {
		return x.ResourceType
	}
	return ""
}

type GetModuleContent_Option struct {
	state         protoimpl.MessageState      `protogen:"open.v1"`
	ModuleCtx     ModuleCtxType               `protobuf:"varint,1,opt,name=module_ctx,json=moduleCtx,proto3,enum=proto.ModuleCtxType" json:"module_ctx,omitempty"`
	Hint          *GetModuleContent_Hint      `protobuf:"bytes,2,opt,name=hint,proto3" json:"hint,omitempty"`
	ExpandMode    GetModuleContent_ExpandMode `protobuf:"varint,4,opt,name=expand_mode,json=expandMode,proto3,enum=proto.GetModuleContent_ExpandMode" json:"expand_mode,omitempty"`
	unknownFields protoimpl.UnknownFields
	sizeCache     protoimpl.SizeCache
}

func (x *GetModuleContent_Option) Reset() {
	*x = GetModuleContent_Option{}
	mi := &file_tflint_proto_msgTypes[51]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *GetModuleContent_Option) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*GetModuleContent_Option) ProtoMessage() {}

func (x *GetModuleContent_Option) ProtoReflect() protoreflect.Message {
	mi := &file_tflint_proto_msgTypes[51]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use GetModuleContent_Option.ProtoReflect.Descriptor instead.
func (*GetModuleContent_Option) Descriptor() ([]byte, []int) {
	return file_tflint_proto_rawDescGZIP(), []int{11, 1}
}

func (x *GetModuleContent_Option) GetModuleCtx() ModuleCtxType {
	if x != nil {
		return x.ModuleCtx
	}
	return ModuleCtxType_MODULE_CTX_TYPE_UNSPECIFIED
}

func (x *GetModuleContent_Option) GetHint() *GetModuleContent_Hint {
	if x != nil {
		return x.Hint
	}
	return nil
}

func (x *GetModuleContent_Option) GetExpandMode() GetModuleContent_ExpandMode {
	if x != nil {
		return x.ExpandMode
	}
	return GetModuleContent_EXPAND_MODE_UNSPECIFIED
}

type GetModuleContent_Request struct {
	state         protoimpl.MessageState   `protogen:"open.v1"`
	Schema        *BodySchema              `protobuf:"bytes,1,opt,name=schema,proto3" json:"schema,omitempty"`
	Option        *GetModuleContent_Option `protobuf:"bytes,2,opt,name=option,proto3" json:"option,omitempty"`
	unknownFields protoimpl.UnknownFields
	sizeCache     protoimpl.SizeCache
}

func (x *GetModuleContent_Request) Reset() {
	*x = GetModuleContent_Request{}
	mi := &file_tflint_proto_msgTypes[52]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *GetModuleContent_Request) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*GetModuleContent_Request) ProtoMessage() {}

func (x *GetModuleContent_Request) ProtoReflect() protoreflect.Message {
	mi := &file_tflint_proto_msgTypes[52]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use GetModuleContent_Request.ProtoReflect.Descriptor instead.
func (*GetModuleContent_Request) Descriptor() ([]byte, []int) {
	return file_tflint_proto_rawDescGZIP(), []int{11, 2}
}

func (x *GetModuleContent_Request) GetSchema() *BodySchema {
	if x != nil {
		return x.Schema
	}
	return nil
}

func (x *GetModuleContent_Request) GetOption() *GetModuleContent_Option {
	if x != nil {
		return x.Option
	}
	return nil
}

type GetModuleContent_Response struct {
	state         protoimpl.MessageState `protogen:"open.v1"`
	Content       *BodyContent           `protobuf:"bytes,1,opt,name=content,proto3" json:"content,omitempty"`
	unknownFields protoimpl.UnknownFields
	sizeCache     protoimpl.SizeCache
}

func (x *GetModuleContent_Response) Reset() {
	*x = GetModuleContent_Response{}
	mi := &file_tflint_proto_msgTypes[53]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *GetModuleContent_Response) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*GetModuleContent_Response) ProtoMessage() {}

func (x *GetModuleContent_Response) ProtoReflect() protoreflect.Message {
	mi := &file_tflint_proto_msgTypes[53]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use GetModuleContent_Response.ProtoReflect.Descriptor instead.
func (*GetModuleContent_Response) Descriptor() ([]byte, []int) {
	return file_tflint_proto_rawDescGZIP(), []int{11, 3}
}

func (x *GetModuleContent_Response) GetContent() *BodyContent {
	if x != nil {
		return x.Content
	}
	return nil
}

type GetFile_Request struct {
	state         protoimpl.MessageState `protogen:"open.v1"`
	Name          string                 `protobuf:"bytes,1,opt,name=name,proto3" json:"name,omitempty"`
	unknownFields protoimpl.UnknownFields
	sizeCache     protoimpl.SizeCache
}

func (x *GetFile_Request) Reset() {
	*x = GetFile_Request{}
	mi := &file_tflint_proto_msgTypes[54]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *GetFile_Request) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*GetFile_Request) ProtoMessage() {}

func (x *GetFile_Request) ProtoReflect() protoreflect.Message {
	mi := &file_tflint_proto_msgTypes[54]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use GetFile_Request.ProtoReflect.Descriptor instead.
func (*GetFile_Request) Descriptor() ([]byte, []int) {
	return file_tflint_proto_rawDescGZIP(), []int{12, 0}
}

func (x *GetFile_Request) GetName() string {
	if x != nil {
		return x.Name
	}
	return ""
}

type GetFile_Response struct {
	state         protoimpl.MessageState `protogen:"open.v1"`
	File          []byte                 `protobuf:"bytes,1,opt,name=file,proto3" json:"file,omitempty"`
	unknownFields protoimpl.UnknownFields
	sizeCache     protoimpl.SizeCache
}

func (x *GetFile_Response) Reset() {
	*x = GetFile_Response{}
	mi := &file_tflint_proto_msgTypes[55]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *GetFile_Response) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*GetFile_Response) ProtoMessage() {}

func (x *GetFile_Response) ProtoReflect() protoreflect.Message {
	mi := &file_tflint_proto_msgTypes[55]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use GetFile_Response.ProtoReflect.Descriptor instead.
func (*GetFile_Response) Descriptor() ([]byte, []int) {
	return file_tflint_proto_rawDescGZIP(), []int{12, 1}
}

func (x *GetFile_Response) GetFile() []byte {
	if x != nil {
		return x.File
	}
	return nil
}

type GetFiles_Request struct {
	state         protoimpl.MessageState `protogen:"open.v1"`
	unknownFields protoimpl.UnknownFields
	sizeCache     protoimpl.SizeCache
}

func (x *GetFiles_Request) Reset() {
	*x = GetFiles_Request{}
	mi := &file_tflint_proto_msgTypes[56]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *GetFiles_Request) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*GetFiles_Request) ProtoMessage() {}

func (x *GetFiles_Request) ProtoReflect() protoreflect.Message {
	mi := &file_tflint_proto_msgTypes[56]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use GetFiles_Request.ProtoReflect.Descriptor instead.
func (*GetFiles_Request) Descriptor() ([]byte, []int) {
	return file_tflint_proto_rawDescGZIP(), []int{13, 0}
}

type GetFiles_Response struct {
	state         protoimpl.MessageState `protogen:"open.v1"`
	Files         map[string][]byte      `protobuf:"bytes,1,rep,name=files,proto3" json:"files,omitempty" protobuf_key:"bytes,1,opt,name=key" protobuf_val:"bytes,2,opt,name=value"`
	unknownFields protoimpl.UnknownFields
	sizeCache     protoimpl.SizeCache
}

func (x *GetFiles_Response) Reset() {
	*x = GetFiles_Response{}
	mi := &file_tflint_proto_msgTypes[57]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *GetFiles_Response) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*GetFiles_Response) ProtoMessage() {}

func (x *GetFiles_Response) ProtoReflect() protoreflect.Message {
	mi := &file_tflint_proto_msgTypes[57]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use GetFiles_Response.ProtoReflect.Descriptor instead.
func (*GetFiles_Response) Descriptor() ([]byte, []int) {
	return file_tflint_proto_rawDescGZIP(), []int{13, 1}
}

func (x *GetFiles_Response) GetFiles() map[string][]byte {
	if x != nil {
		return x.Files
	}
	return nil
}

type GetRuleConfigContent_Request struct {
	state         protoimpl.MessageState `protogen:"open.v1"`
	Name          string                 `protobuf:"bytes,1,opt,name=name,proto3" json:"name,omitempty"`
	Schema        *BodySchema            `protobuf:"bytes,2,opt,name=schema,proto3" json:"schema,omitempty"`
	unknownFields protoimpl.UnknownFields
	sizeCache     protoimpl.SizeCache
}

func (x *GetRuleConfigContent_Request) Reset() {
	*x = GetRuleConfigContent_Request{}
	mi := &file_tflint_proto_msgTypes[59]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *GetRuleConfigContent_Request) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*GetRuleConfigContent_Request) ProtoMessage() {}

func (x *GetRuleConfigContent_Request) ProtoReflect() protoreflect.Message {
	mi := &file_tflint_proto_msgTypes[59]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use GetRuleConfigContent_Request.ProtoReflect.Descriptor instead.
func (*GetRuleConfigContent_Request) Descriptor() ([]byte, []int) {
	return file_tflint_proto_rawDescGZIP(), []int{14, 0}
}

func (x *GetRuleConfigContent_Request) GetName() string {
	if x != nil {
		return x.Name
	}
	return ""
}

func (x *GetRuleConfigContent_Request) GetSchema() *BodySchema {
	if x != nil {
		return x.Schema
	}
	return nil
}

type GetRuleConfigContent_Response struct {
	state         protoimpl.MessageState `protogen:"open.v1"`
	Content       *BodyContent           `protobuf:"bytes,1,opt,name=content,proto3" json:"content,omitempty"`
	unknownFields protoimpl.UnknownFields
	sizeCache     protoimpl.SizeCache
}

func (x *GetRuleConfigContent_Response) Reset() {
	*x = GetRuleConfigContent_Response{}
	mi := &file_tflint_proto_msgTypes[60]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *GetRuleConfigContent_Response) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*GetRuleConfigContent_Response) ProtoMessage() {}

func (x *GetRuleConfigContent_Response) ProtoReflect() protoreflect.Message {
	mi := &file_tflint_proto_msgTypes[60]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use GetRuleConfigContent_Response.ProtoReflect.Descriptor instead.
func (*GetRuleConfigContent_Response) Descriptor() ([]byte, []int) {
	return file_tflint_proto_rawDescGZIP(), []int{14, 1}
}

func (x *GetRuleConfigContent_Response) GetContent() *BodyContent {
	if x != nil {
		return x.Content
	}
	return nil
}

type EvaluateExpr_Option struct {
	state         protoimpl.MessageState `protogen:"open.v1"`
	Type          []byte                 `protobuf:"bytes,1,opt,name=type,proto3" json:"type,omitempty"`
	ModuleCtx     ModuleCtxType          `protobuf:"varint,2,opt,name=module_ctx,json=moduleCtx,proto3,enum=proto.ModuleCtxType" json:"module_ctx,omitempty"`
	unknownFields protoimpl.UnknownFields
	sizeCache     protoimpl.SizeCache
}

func (x *EvaluateExpr_Option) Reset() {
	*x = EvaluateExpr_Option{}
	mi := &file_tflint_proto_msgTypes[61]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *EvaluateExpr_Option) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*EvaluateExpr_Option) ProtoMessage() {}

func (x *EvaluateExpr_Option) ProtoReflect() protoreflect.Message {
	mi := &file_tflint_proto_msgTypes[61]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use EvaluateExpr_Option.ProtoReflect.Descriptor instead.
func (*EvaluateExpr_Option) Descriptor() ([]byte, []int) {
	return file_tflint_proto_rawDescGZIP(), []int{15, 0}
}

func (x *EvaluateExpr_Option) GetType() []byte {
	if x != nil {
		return x.Type
	}
	return nil
}

func (x *EvaluateExpr_Option) GetModuleCtx() ModuleCtxType {
	if x != nil {
		return x.ModuleCtx
	}
	return ModuleCtxType_MODULE_CTX_TYPE_UNSPECIFIED
}

type EvaluateExpr_Request struct {
	state         protoimpl.MessageState `protogen:"open.v1"`
	Option        *EvaluateExpr_Option   `protobuf:"bytes,3,opt,name=option,proto3" json:"option,omitempty"`
	Expression    *Expression            `protobuf:"bytes,4,opt,name=expression,proto3" json:"expression,omitempty"`
	unknownFields protoimpl.UnknownFields
	sizeCache     protoimpl.SizeCache
}

func (x *EvaluateExpr_Request) Reset() {
	*x = EvaluateExpr_Request{}
	mi := &file_tflint_proto_msgTypes[62]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *EvaluateExpr_Request) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*EvaluateExpr_Request) ProtoMessage() {}

func (x *EvaluateExpr_Request) ProtoReflect() protoreflect.Message {
	mi := &file_tflint_proto_msgTypes[62]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use EvaluateExpr_Request.ProtoReflect.Descriptor instead.
func (*EvaluateExpr_Request) Descriptor() ([]byte, []int) {
	return file_tflint_proto_rawDescGZIP(), []int{15, 1}
}

func (x *EvaluateExpr_Request) GetOption() *EvaluateExpr_Option {
	if x != nil {
		return x.Option
	}
	return nil
}

func (x *EvaluateExpr_Request) GetExpression() *Expression {
	if x != nil {
		return x.Expression
	}
	return nil
}

type EvaluateExpr_Response struct {
	state         protoimpl.MessageState `protogen:"open.v1"`
	Value         []byte                 `protobuf:"bytes,1,opt,name=value,proto3" json:"value,omitempty"`
	Marks         []*ValueMark           `protobuf:"bytes,2,rep,name=marks,proto3" json:"marks,omitempty"`
	unknownFields protoimpl.UnknownFields
	sizeCache     protoimpl.SizeCache
}

func (x *EvaluateExpr_Response) Reset() {
	*x = EvaluateExpr_Response{}
	mi := &file_tflint_proto_msgTypes[63]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *EvaluateExpr_Response) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*EvaluateExpr_Response) ProtoMessage() {}

func (x *EvaluateExpr_Response) ProtoReflect() protoreflect.Message {
	mi := &file_tflint_proto_msgTypes[63]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use EvaluateExpr_Response.ProtoReflect.Descriptor instead.
func (*EvaluateExpr_Response) Descriptor() ([]byte, []int) {
	return file_tflint_proto_rawDescGZIP(), []int{15, 2}
}

func (x *EvaluateExpr_Response) GetValue() []byte {
	if x != nil {
		return x.Value
	}
	return nil
}

func (x *EvaluateExpr_Response) GetMarks() []*ValueMark {
	if x != nil {
		return x.Marks
	}
	return nil
}

type EmitIssue_Rule struct {
	state         protoimpl.MessageState `protogen:"open.v1"`
	Name          string                 `protobuf:"bytes,1,opt,name=name,proto3" json:"name,omitempty"`
	Enabled       bool                   `protobuf:"varint,2,opt,name=enabled,proto3" json:"enabled,omitempty"`
	Severity      EmitIssue_Severity     `protobuf:"varint,3,opt,name=severity,proto3,enum=proto.EmitIssue_Severity" json:"severity,omitempty"`
	Link          string                 `protobuf:"bytes,4,opt,name=link,proto3" json:"link,omitempty"`
	unknownFields protoimpl.UnknownFields
	sizeCache     protoimpl.SizeCache
}

func (x *EmitIssue_Rule) Reset() {
	*x = EmitIssue_Rule{}
	mi := &file_tflint_proto_msgTypes[64]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *EmitIssue_Rule) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*EmitIssue_Rule) ProtoMessage() {}

func (x *EmitIssue_Rule) ProtoReflect() protoreflect.Message {
	mi := &file_tflint_proto_msgTypes[64]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use EmitIssue_Rule.ProtoReflect.Descriptor instead.
func (*EmitIssue_Rule) Descriptor() ([]byte, []int) {
	return file_tflint_proto_rawDescGZIP(), []int{16, 0}
}

func (x *EmitIssue_Rule) GetName() string {
	if x != nil {
		return x.Name
	}
	return ""
}

func (x *EmitIssue_Rule) GetEnabled() bool {
	if x != nil {
		return x.Enabled
	}
	return false
}

func (x *EmitIssue_Rule) GetSeverity() EmitIssue_Severity {
	if x != nil {
		return x.Severity
	}
	return EmitIssue_SEVERITY_UNSPECIFIED
}

func (x *EmitIssue_Rule) GetLink() string {
	if x != nil {
		return x.Link
	}
	return ""
}

type EmitIssue_Request struct {
	state         protoimpl.MessageState `protogen:"open.v1"`
	Rule          *EmitIssue_Rule        `protobuf:"bytes,1,opt,name=rule,proto3" json:"rule,omitempty"`
	Message       string                 `protobuf:"bytes,2,opt,name=message,proto3" json:"message,omitempty"`
	Range         *Range                 `protobuf:"bytes,3,opt,name=range,proto3" json:"range,omitempty"`
	Fixable       bool                   `protobuf:"varint,4,opt,name=fixable,proto3" json:"fixable,omitempty"`
	unknownFields protoimpl.UnknownFields
	sizeCache     protoimpl.SizeCache
}

func (x *EmitIssue_Request) Reset() {
	*x = EmitIssue_Request{}
	mi := &file_tflint_proto_msgTypes[65]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *EmitIssue_Request) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*EmitIssue_Request) ProtoMessage() {}

func (x *EmitIssue_Request) ProtoReflect() protoreflect.Message {
	mi := &file_tflint_proto_msgTypes[65]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use EmitIssue_Request.ProtoReflect.Descriptor instead.
func (*EmitIssue_Request) Descriptor() ([]byte, []int) {
	return file_tflint_proto_rawDescGZIP(), []int{16, 1}
}

func (x *EmitIssue_Request) GetRule() *EmitIssue_Rule {
	if x != nil {
		return x.Rule
	}
	return nil
}

func (x *EmitIssue_Request) GetMessage() string {
	if x != nil {
		return x.Message
	}
	return ""
}

func (x *EmitIssue_Request) GetRange() *Range {
	if x != nil {
		return x.Range
	}
	return nil
}

func (x *EmitIssue_Request) GetFixable() bool {
	if x != nil {
		return x.Fixable
	}
	return false
}

type EmitIssue_Response struct {
	state         protoimpl.MessageState `protogen:"open.v1"`
	Applied       bool                   `protobuf:"varint,1,opt,name=applied,proto3" json:"applied,omitempty"`
	unknownFields protoimpl.UnknownFields
	sizeCache     protoimpl.SizeCache
}

func (x *EmitIssue_Response) Reset() {
	*x = EmitIssue_Response{}
	mi := &file_tflint_proto_msgTypes[66]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *EmitIssue_Response) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*EmitIssue_Response) ProtoMessage() {}

func (x *EmitIssue_Response) ProtoReflect() protoreflect.Message {
	mi := &file_tflint_proto_msgTypes[66]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use EmitIssue_Response.ProtoReflect.Descriptor instead.
func (*EmitIssue_Response) Descriptor() ([]byte, []int) {
	return file_tflint_proto_rawDescGZIP(), []int{16, 2}
}

func (x *EmitIssue_Response) GetApplied() bool {
	if x != nil {
		return x.Applied
	}
	return false
}

type ApplyChanges_Request struct {
	state         protoimpl.MessageState `protogen:"open.v1"`
	Changes       map[string][]byte      `protobuf:"bytes,1,rep,name=changes,proto3" json:"changes,omitempty" protobuf_key:"bytes,1,opt,name=key" protobuf_val:"bytes,2,opt,name=value"`
	unknownFields protoimpl.UnknownFields
	sizeCache     protoimpl.SizeCache
}

func (x *ApplyChanges_Request) Reset() {
	*x = ApplyChanges_Request{}
	mi := &file_tflint_proto_msgTypes[67]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *ApplyChanges_Request) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*ApplyChanges_Request) ProtoMessage() {}

func (x *ApplyChanges_Request) ProtoReflect() protoreflect.Message {
	mi := &file_tflint_proto_msgTypes[67]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use ApplyChanges_Request.ProtoReflect.Descriptor instead.
func (*ApplyChanges_Request) Descriptor() ([]byte, []int) {
	return file_tflint_proto_rawDescGZIP(), []int{17, 0}
}

func (x *ApplyChanges_Request) GetChanges() map[string][]byte {
	if x != nil {
		return x.Changes
	}
	return nil
}

type ApplyChanges_Response struct {
	state         protoimpl.MessageState `protogen:"open.v1"`
	unknownFields protoimpl.UnknownFields
	sizeCache     protoimpl.SizeCache
}

func (x *ApplyChanges_Response) Reset() {
	*x = ApplyChanges_Response{}
	mi := &file_tflint_proto_msgTypes[68]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *ApplyChanges_Response) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*ApplyChanges_Response) ProtoMessage() {}

func (x *ApplyChanges_Response) ProtoReflect() protoreflect.Message {
	mi := &file_tflint_proto_msgTypes[68]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use ApplyChanges_Response.ProtoReflect.Descriptor instead.
func (*ApplyChanges_Response) Descriptor() ([]byte, []int) {
	return file_tflint_proto_rawDescGZIP(), []int{17, 1}
}

type BodySchema_Attribute struct {
	state         protoimpl.MessageState `protogen:"open.v1"`
	Name          string                 `protobuf:"bytes,1,opt,name=name,proto3" json:"name,omitempty"`
	Required      bool                   `protobuf:"varint,2,opt,name=required,proto3" json:"required,omitempty"`
	unknownFields protoimpl.UnknownFields
	sizeCache     protoimpl.SizeCache
}

func (x *BodySchema_Attribute) Reset() {
	*x = BodySchema_Attribute{}
	mi := &file_tflint_proto_msgTypes[70]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *BodySchema_Attribute) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*BodySchema_Attribute) ProtoMessage() {}

func (x *BodySchema_Attribute) ProtoReflect() protoreflect.Message {
	mi := &file_tflint_proto_msgTypes[70]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use BodySchema_Attribute.ProtoReflect.Descriptor instead.
func (*BodySchema_Attribute) Descriptor() ([]byte, []int) {
	return file_tflint_proto_rawDescGZIP(), []int{18, 0}
}

func (x *BodySchema_Attribute) GetName() string {
	if x != nil {
		return x.Name
	}
	return ""
}

func (x *BodySchema_Attribute) GetRequired() bool {
	if x != nil {
		return x.Required
	}
	return false
}

type BodySchema_Block struct {
	state         protoimpl.MessageState `protogen:"open.v1"`
	Type          string                 `protobuf:"bytes,1,opt,name=type,proto3" json:"type,omitempty"`
	LabelNames    []string               `protobuf:"bytes,2,rep,name=label_names,json=labelNames,proto3" json:"label_names,omitempty"`
	Body          *BodySchema            `protobuf:"bytes,3,opt,name=body,proto3" json:"body,omitempty"`
	unknownFields protoimpl.UnknownFields
	sizeCache     protoimpl.SizeCache
}

func (x *BodySchema_Block) Reset() {
	*x = BodySchema_Block{}
	mi := &file_tflint_proto_msgTypes[71]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *BodySchema_Block) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*BodySchema_Block) ProtoMessage() {}

func (x *BodySchema_Block) ProtoReflect() protoreflect.Message {
	mi := &file_tflint_proto_msgTypes[71]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use BodySchema_Block.ProtoReflect.Descriptor instead.
func (*BodySchema_Block) Descriptor() ([]byte, []int) {
	return file_tflint_proto_rawDescGZIP(), []int{18, 1}
}

func (x *BodySchema_Block) GetType() string {
	if x != nil {
		return x.Type
	}
	return ""
}

func (x *BodySchema_Block) GetLabelNames() []string {
	if x != nil {
		return x.LabelNames
	}
	return nil
}

func (x *BodySchema_Block) GetBody() *BodySchema {
	if x != nil {
		return x.Body
	}
	return nil
}

type BodyContent_Attribute struct {
	state         protoimpl.MessageState `protogen:"open.v1"`
	Name          string                 `protobuf:"bytes,1,opt,name=name,proto3" json:"name,omitempty"`
	Range         *Range                 `protobuf:"bytes,4,opt,name=range,proto3" json:"range,omitempty"`
	NameRange     *Range                 `protobuf:"bytes,5,opt,name=name_range,json=nameRange,proto3" json:"name_range,omitempty"`
	Expression    *Expression            `protobuf:"bytes,6,opt,name=expression,proto3" json:"expression,omitempty"`
	unknownFields protoimpl.UnknownFields
	sizeCache     protoimpl.SizeCache
}

func (x *BodyContent_Attribute) Reset() {
	*x = BodyContent_Attribute{}
	mi := &file_tflint_proto_msgTypes[72]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *BodyContent_Attribute) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*BodyContent_Attribute) ProtoMessage() {}

func (x *BodyContent_Attribute) ProtoReflect() protoreflect.Message {
	mi := &file_tflint_proto_msgTypes[72]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use BodyContent_Attribute.ProtoReflect.Descriptor instead.
func (*BodyContent_Attribute) Descriptor() ([]byte, []int) {
	return file_tflint_proto_rawDescGZIP(), []int{19, 0}
}

func (x *BodyContent_Attribute) GetName() string {
	if x != nil {
		return x.Name
	}
	return ""
}

func (x *BodyContent_Attribute) GetRange() *Range {
	if x != nil {
		return x.Range
	}
	return nil
}

func (x *BodyContent_Attribute) GetNameRange() *Range {
	if x != nil {
		return x.NameRange
	}
	return nil
}

func (x *BodyContent_Attribute) GetExpression() *Expression {
	if x != nil {
		return x.Expression
	}
	return nil
}

type BodyContent_Block struct {
	state         protoimpl.MessageState `protogen:"open.v1"`
	Type          string                 `protobuf:"bytes,1,opt,name=type,proto3" json:"type,omitempty"`
	Labels        []string               `protobuf:"bytes,2,rep,name=labels,proto3" json:"labels,omitempty"`
	Body          *BodyContent           `protobuf:"bytes,3,opt,name=body,proto3" json:"body,omitempty"`
	DefRange      *Range                 `protobuf:"bytes,4,opt,name=def_range,json=defRange,proto3" json:"def_range,omitempty"`
	TypeRange     *Range                 `protobuf:"bytes,5,opt,name=type_range,json=typeRange,proto3" json:"type_range,omitempty"`
	LabelRanges   []*Range               `protobuf:"bytes,6,rep,name=label_ranges,json=labelRanges,proto3" json:"label_ranges,omitempty"`
	unknownFields protoimpl.UnknownFields
	sizeCache     protoimpl.SizeCache
}

func (x *BodyContent_Block) Reset() {
	*x = BodyContent_Block{}
	mi := &file_tflint_proto_msgTypes[73]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *BodyContent_Block) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*BodyContent_Block) ProtoMessage() {}

func (x *BodyContent_Block) ProtoReflect() protoreflect.Message {
	mi := &file_tflint_proto_msgTypes[73]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use BodyContent_Block.ProtoReflect.Descriptor instead.
func (*BodyContent_Block) Descriptor() ([]byte, []int) {
	return file_tflint_proto_rawDescGZIP(), []int{19, 1}
}

func (x *BodyContent_Block) GetType() string {
	if x != nil {
		return x.Type
	}
	return ""
}

func (x *BodyContent_Block) GetLabels() []string {
	if x != nil {
		return x.Labels
	}
	return nil
}

func (x *BodyContent_Block) GetBody() *BodyContent {
	if x != nil {
		return x.Body
	}
	return nil
}

func (x *BodyContent_Block) GetDefRange() *Range {
	if x != nil {
		return x.DefRange
	}
	return nil
}

func (x *BodyContent_Block) GetTypeRange() *Range {
	if x != nil {
		return x.TypeRange
	}
	return nil
}

func (x *BodyContent_Block) GetLabelRanges() []*Range {
	if x != nil {
		return x.LabelRanges
	}
	return nil
}

type Range_Pos struct {
	state         protoimpl.MessageState `protogen:"open.v1"`
	Line          int64                  `protobuf:"varint,1,opt,name=line,proto3" json:"line,omitempty"`
	Column        int64                  `protobuf:"varint,2,opt,name=column,proto3" json:"column,omitempty"`
	Byte          int64                  `protobuf:"varint,3,opt,name=byte,proto3" json:"byte,omitempty"`
	unknownFields protoimpl.UnknownFields
	sizeCache     protoimpl.SizeCache
}

func (x *Range_Pos) Reset() {
	*x = Range_Pos{}
	mi := &file_tflint_proto_msgTypes[75]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *Range_Pos) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*Range_Pos) ProtoMessage() {}

func (x *Range_Pos) ProtoReflect() protoreflect.Message {
	mi := &file_tflint_proto_msgTypes[75]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use Range_Pos.ProtoReflect.Descriptor instead.
func (*Range_Pos) Descriptor() ([]byte, []int) {
	return file_tflint_proto_rawDescGZIP(), []int{21, 0}
}

func (x *Range_Pos) GetLine() int64 {
	if x != nil {
		return x.Line
	}
	return 0
}

func (x *Range_Pos) GetColumn() int64 {
	if x != nil {
		return x.Column
	}
	return 0
}

func (x *Range_Pos) GetByte() int64 {
	if x != nil {
		return x.Byte
	}
	return 0
}

type AttributePath_Step struct {
	state protoimpl.MessageState `protogen:"open.v1"`
	// Types that are valid to be assigned to Selector:
	//
	//	*AttributePath_Step_AttributeName
	//	*AttributePath_Step_ElementKeyString
	//	*AttributePath_Step_ElementKeyInt
	Selector      isAttributePath_Step_Selector `protobuf_oneof:"selector"`
	unknownFields protoimpl.UnknownFields
	sizeCache     protoimpl.SizeCache
}

func (x *AttributePath_Step) Reset() {
	*x = AttributePath_Step{}
	mi := &file_tflint_proto_msgTypes[76]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *AttributePath_Step) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*AttributePath_Step) ProtoMessage() {}

func (x *AttributePath_Step) ProtoReflect() protoreflect.Message {
	mi := &file_tflint_proto_msgTypes[76]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use AttributePath_Step.ProtoReflect.Descriptor instead.
func (*AttributePath_Step) Descriptor() ([]byte, []int) {
	return file_tflint_proto_rawDescGZIP(), []int{22, 0}
}

func (x *AttributePath_Step) GetSelector() isAttributePath_Step_Selector {
	if x != nil {
		return x.Selector
	}
	return nil
}

func (x *AttributePath_Step) GetAttributeName() string {
	if x != nil {
		if x, ok := x.Selector.(*AttributePath_Step_AttributeName); ok {
			return x.AttributeName
		}
	}
	return ""
}

func (x *AttributePath_Step) GetElementKeyString() string {
	if x != nil {
		if x, ok := x.Selector.(*AttributePath_Step_ElementKeyString); ok {
			return x.ElementKeyString
		}
	}
	return ""
}

func (x *AttributePath_Step) GetElementKeyInt() int64 {
	if x != nil {
		if x, ok := x.Selector.(*AttributePath_Step_ElementKeyInt); ok {
			return x.ElementKeyInt
		}
	}
	return 0
}

type isAttributePath_Step_Selector interface {
	isAttributePath_Step_Selector()
}

type AttributePath_Step_AttributeName struct {
	AttributeName string `protobuf:"bytes,1,opt,name=attribute_name,json=attributeName,proto3,oneof"`
}

type AttributePath_Step_ElementKeyString struct {
	ElementKeyString string `protobuf:"bytes,2,opt,name=element_key_string,json=elementKeyString,proto3,oneof"`
}

type AttributePath_Step_ElementKeyInt struct {
	ElementKeyInt int64 `protobuf:"varint,3,opt,name=element_key_int,json=elementKeyInt,proto3,oneof"`
}

func (*AttributePath_Step_AttributeName) isAttributePath_Step_Selector() {}

func (*AttributePath_Step_ElementKeyString) isAttributePath_Step_Selector() {}

func (*AttributePath_Step_ElementKeyInt) isAttributePath_Step_Selector() {}

var File_tflint_proto protoreflect.FileDescriptor

var file_tflint_proto_rawDesc = []byte{
	0x0a, 0x0c, 0x74, 0x66, 0x6c, 0x69, 0x6e, 0x74, 0x2e, 0x70, 0x72, 0x6f, 0x74, 0x6f, 0x12, 0x05,
	0x70, 0x72, 0x6f, 0x74, 0x6f, 0x22, 0x34, 0x0a, 0x07, 0x47, 0x65, 0x74, 0x4e, 0x61, 0x6d, 0x65,
	0x1a, 0x09, 0x0a, 0x07, 0x52, 0x65, 0x71, 0x75, 0x65, 0x73, 0x74, 0x1a, 0x1e, 0x0a, 0x08, 0x52,
	0x65, 0x73, 0x70, 0x6f, 0x6e, 0x73, 0x65, 0x12, 0x12, 0x0a, 0x04, 0x6e, 0x61, 0x6d, 0x65, 0x18,
	0x01, 0x20, 0x01, 0x28, 0x09, 0x52, 0x04, 0x6e, 0x61, 0x6d, 0x65, 0x22, 0x3d, 0x0a, 0x0a, 0x47,
	0x65, 0x74, 0x56, 0x65, 0x72, 0x73, 0x69, 0x6f, 0x6e, 0x1a, 0x09, 0x0a, 0x07, 0x52, 0x65, 0x71,
	0x75, 0x65, 0x73, 0x74, 0x1a, 0x24, 0x0a, 0x08, 0x52, 0x65, 0x73, 0x70, 0x6f, 0x6e, 0x73, 0x65,
	0x12, 0x18, 0x0a, 0x07, 0x76, 0x65, 0x72, 0x73, 0x69, 0x6f, 0x6e, 0x18, 0x01, 0x20, 0x01, 0x28,
	0x09, 0x52, 0x07, 0x76, 0x65, 0x72, 0x73, 0x69, 0x6f, 0x6e, 0x22, 0x4d, 0x0a, 0x14, 0x47, 0x65,
	0x74, 0x56, 0x65, 0x72, 0x73, 0x69, 0x6f, 0x6e, 0x43, 0x6f, 0x6e, 0x73, 0x74, 0x72, 0x61, 0x69,
	0x6e, 0x74, 0x1a, 0x09, 0x0a, 0x07, 0x52, 0x65, 0x71, 0x75, 0x65, 0x73, 0x74, 0x1a, 0x2a, 0x0a,
	0x08, 0x52, 0x65, 0x73, 0x70, 0x6f, 0x6e, 0x73, 0x65, 0x12, 0x1e, 0x0a, 0x0a, 0x63, 0x6f, 0x6e,
	0x73, 0x74, 0x72, 0x61, 0x69, 0x6e, 0x74, 0x18, 0x01, 0x20, 0x01, 0x28, 0x09, 0x52, 0x0a, 0x63,
	0x6f, 0x6e, 0x73, 0x74, 0x72, 0x61, 0x69, 0x6e, 0x74, 0x22, 0x40, 0x0a, 0x0d, 0x47, 0x65, 0x74,
	0x53, 0x44, 0x4b, 0x56, 0x65, 0x72, 0x73, 0x69, 0x6f, 0x6e, 0x1a, 0x09, 0x0a, 0x07, 0x52, 0x65,
	0x71, 0x75, 0x65, 0x73, 0x74, 0x1a, 0x24, 0x0a, 0x08, 0x52, 0x65, 0x73, 0x70, 0x6f, 0x6e, 0x73,
	0x65, 0x12, 0x18, 0x0a, 0x07, 0x76, 0x65, 0x72, 0x73, 0x69, 0x6f, 0x6e, 0x18, 0x01, 0x20, 0x01,
	0x28, 0x09, 0x52, 0x07, 0x76, 0x65, 0x72, 0x73, 0x69, 0x6f, 0x6e, 0x22, 0x3b, 0x0a, 0x0c, 0x47,
	0x65, 0x74, 0x52, 0x75, 0x6c, 0x65, 0x4e, 0x61, 0x6d, 0x65, 0x73, 0x1a, 0x09, 0x0a, 0x07, 0x52,
	0x65, 0x71, 0x75, 0x65, 0x73, 0x74, 0x1a, 0x20, 0x0a, 0x08, 0x52, 0x65, 0x73, 0x70, 0x6f, 0x6e,
	0x73, 0x65, 0x12, 0x14, 0x0a, 0x05, 0x6e, 0x61, 0x6d, 0x65, 0x73, 0x18, 0x01, 0x20, 0x03, 0x28,
	0x09, 0x52, 0x05, 0x6e, 0x61, 0x6d, 0x65, 0x73, 0x22, 0x53, 0x0a, 0x0f, 0x47, 0x65, 0x74, 0x43,
	0x6f, 0x6e, 0x66, 0x69, 0x67, 0x53, 0x63, 0x68, 0x65, 0x6d, 0x61, 0x1a, 0x09, 0x0a, 0x07, 0x52,
	0x65, 0x71, 0x75, 0x65, 0x73, 0x74, 0x1a, 0x35, 0x0a, 0x08, 0x52, 0x65, 0x73, 0x70, 0x6f, 0x6e,
	0x73, 0x65, 0x12, 0x29, 0x0a, 0x06, 0x73, 0x63, 0x68, 0x65, 0x6d, 0x61, 0x18, 0x01, 0x20, 0x01,
	0x28, 0x0b, 0x32, 0x11, 0x2e, 0x70, 0x72, 0x6f, 0x74, 0x6f, 0x2e, 0x42, 0x6f, 0x64, 0x79, 0x53,
	0x63, 0x68, 0x65, 0x6d, 0x61, 0x52, 0x06, 0x73, 0x63, 0x68, 0x65, 0x6d, 0x61, 0x22, 0xa1, 0x03,
	0x0a, 0x11, 0x41, 0x70, 0x70, 0x6c, 0x79, 0x47, 0x6c, 0x6f, 0x62, 0x61, 0x6c, 0x43, 0x6f, 0x6e,
	0x66, 0x69, 0x67, 0x1a, 0xff, 0x01, 0x0a, 0x06, 0x43, 0x6f, 0x6e, 0x66, 0x69, 0x67, 0x12, 0x40,
	0x0a, 0x05, 0x72, 0x75, 0x6c, 0x65, 0x73, 0x18, 0x01, 0x20, 0x03, 0x28, 0x0b, 0x32, 0x2a, 0x2e,
	0x70, 0x72, 0x6f, 0x74, 0x6f, 0x2e, 0x41, 0x70, 0x70, 0x6c, 0x79, 0x47, 0x6c, 0x6f, 0x62, 0x61,
	0x6c, 0x43, 0x6f, 0x6e, 0x66, 0x69, 0x67, 0x2e, 0x43, 0x6f, 0x6e, 0x66, 0x69, 0x67, 0x2e, 0x52,
	0x75, 0x6c, 0x65, 0x73, 0x45, 0x6e, 0x74, 0x72, 0x79, 0x52, 0x05, 0x72, 0x75, 0x6c, 0x65, 0x73,
	0x12, 0x2e, 0x0a, 0x13, 0x64, 0x69, 0x73, 0x61, 0x62, 0x6c, 0x65, 0x64, 0x5f, 0x62, 0x79, 0x5f,
	0x64, 0x65, 0x66, 0x61, 0x75, 0x6c, 0x74, 0x18, 0x02, 0x20, 0x01, 0x28, 0x08, 0x52, 0x11, 0x64,
	0x69, 0x73, 0x61, 0x62, 0x6c, 0x65, 0x64, 0x42, 0x79, 0x44, 0x65, 0x66, 0x61, 0x75, 0x6c, 0x74,
	0x12, 0x12, 0x0a, 0x04, 0x6f, 0x6e, 0x6c, 0x79, 0x18, 0x03, 0x20, 0x03, 0x28, 0x09, 0x52, 0x04,
	0x6f, 0x6e, 0x6c, 0x79, 0x12, 0x10, 0x0a, 0x03, 0x66, 0x69, 0x78, 0x18, 0x04, 0x20, 0x01, 0x28,
	0x08, 0x52, 0x03, 0x66, 0x69, 0x78, 0x1a, 0x5d, 0x0a, 0x0a, 0x52, 0x75, 0x6c, 0x65, 0x73, 0x45,
	0x6e, 0x74, 0x72, 0x79, 0x12, 0x10, 0x0a, 0x03, 0x6b, 0x65, 0x79, 0x18, 0x01, 0x20, 0x01, 0x28,
	0x09, 0x52, 0x03, 0x6b, 0x65, 0x79, 0x12, 0x39, 0x0a, 0x05, 0x76, 0x61, 0x6c, 0x75, 0x65, 0x18,
	0x02, 0x20, 0x01, 0x28, 0x0b, 0x32, 0x23, 0x2e, 0x70, 0x72, 0x6f, 0x74, 0x6f, 0x2e, 0x41, 0x70,
	0x70, 0x6c, 0x79, 0x47, 0x6c, 0x6f, 0x62, 0x61, 0x6c, 0x43, 0x6f, 0x6e, 0x66, 0x69, 0x67, 0x2e,
	0x52, 0x75, 0x6c, 0x65, 0x43, 0x6f, 0x6e, 0x66, 0x69, 0x67, 0x52, 0x05, 0x76, 0x61, 0x6c, 0x75,
	0x65, 0x3a, 0x02, 0x38, 0x01, 0x1a, 0x3a, 0x0a, 0x0a, 0x52, 0x75, 0x6c, 0x65, 0x43, 0x6f, 0x6e,
	0x66, 0x69, 0x67, 0x12, 0x12, 0x0a, 0x04, 0x6e, 0x61, 0x6d, 0x65, 0x18, 0x01, 0x20, 0x01, 0x28,
	0x09, 0x52, 0x04, 0x6e, 0x61, 0x6d, 0x65, 0x12, 0x18, 0x0a, 0x07, 0x65, 0x6e, 0x61, 0x62, 0x6c,
	0x65, 0x64, 0x18, 0x02, 0x20, 0x01, 0x28, 0x08, 0x52, 0x07, 0x65, 0x6e, 0x61, 0x62, 0x6c, 0x65,
	0x64, 0x1a, 0x42, 0x0a, 0x07, 0x52, 0x65, 0x71, 0x75, 0x65, 0x73, 0x74, 0x12, 0x37, 0x0a, 0x06,
	0x63, 0x6f, 0x6e, 0x66, 0x69, 0x67, 0x18, 0x01, 0x20, 0x01, 0x28, 0x0b, 0x32, 0x1f, 0x2e, 0x70,
	0x72, 0x6f, 0x74, 0x6f, 0x2e, 0x41, 0x70, 0x70, 0x6c, 0x79, 0x47, 0x6c, 0x6f, 0x62, 0x61, 0x6c,
	0x43, 0x6f, 0x6e, 0x66, 0x69, 0x67, 0x2e, 0x43, 0x6f, 0x6e, 0x66, 0x69, 0x67, 0x52, 0x06, 0x63,
	0x6f, 0x6e, 0x66, 0x69, 0x67, 0x1a, 0x0a, 0x0a, 0x08, 0x52, 0x65, 0x73, 0x70, 0x6f, 0x6e, 0x73,
	0x65, 0x22, 0x52, 0x0a, 0x0b, 0x41, 0x70, 0x70, 0x6c, 0x79, 0x43, 0x6f, 0x6e, 0x66, 0x69, 0x67,
	0x1a, 0x37, 0x0a, 0x07, 0x52, 0x65, 0x71, 0x75, 0x65, 0x73, 0x74, 0x12, 0x2c, 0x0a, 0x07, 0x63,
	0x6f, 0x6e, 0x74, 0x65, 0x6e, 0x74, 0x18, 0x01, 0x20, 0x01, 0x28, 0x0b, 0x32, 0x12, 0x2e, 0x70,
	0x72, 0x6f, 0x74, 0x6f, 0x2e, 0x42, 0x6f, 0x64, 0x79, 0x43, 0x6f, 0x6e, 0x74, 0x65, 0x6e, 0x74,
	0x52, 0x07, 0x63, 0x6f, 0x6e, 0x74, 0x65, 0x6e, 0x74, 0x1a, 0x0a, 0x0a, 0x08, 0x52, 0x65, 0x73,
	0x70, 0x6f, 0x6e, 0x73, 0x65, 0x22, 0x36, 0x0a, 0x05, 0x43, 0x68, 0x65, 0x63, 0x6b, 0x1a, 0x21,
	0x0a, 0x07, 0x52, 0x65, 0x71, 0x75, 0x65, 0x73, 0x74, 0x12, 0x16, 0x0a, 0x06, 0x72, 0x75, 0x6e,
	0x6e, 0x65, 0x72, 0x18, 0x01, 0x20, 0x01, 0x28, 0x0d, 0x52, 0x06, 0x72, 0x75, 0x6e, 0x6e, 0x65,
	0x72, 0x1a, 0x0a, 0x0a, 0x08, 0x52, 0x65, 0x73, 0x70, 0x6f, 0x6e, 0x73, 0x65, 0x22, 0x3a, 0x0a,
	0x0d, 0x47, 0x65, 0x74, 0x4f, 0x72, 0x69, 0x67, 0x69, 0x6e, 0x61, 0x6c, 0x77, 0x64, 0x1a, 0x09,
	0x0a, 0x07, 0x52, 0x65, 0x71, 0x75, 0x65, 0x73, 0x74, 0x1a, 0x1e, 0x0a, 0x08, 0x52, 0x65, 0x73,
	0x70, 0x6f, 0x6e, 0x73, 0x65, 0x12, 0x12, 0x0a, 0x04, 0x70, 0x61, 0x74, 0x68, 0x18, 0x01, 0x20,
	0x01, 0x28, 0x09, 0x52, 0x04, 0x70, 0x61, 0x74, 0x68, 0x22, 0x3a, 0x0a, 0x0d, 0x47, 0x65, 0x74,
	0x4d, 0x6f, 0x64, 0x75, 0x6c, 0x65, 0x50, 0x61, 0x74, 0x68, 0x1a, 0x09, 0x0a, 0x07, 0x52, 0x65,
	0x71, 0x75, 0x65, 0x73, 0x74, 0x1a, 0x1e, 0x0a, 0x08, 0x52, 0x65, 0x73, 0x70, 0x6f, 0x6e, 0x73,
	0x65, 0x12, 0x12, 0x0a, 0x04, 0x70, 0x61, 0x74, 0x68, 0x18, 0x01, 0x20, 0x03, 0x28, 0x09, 0x52,
	0x04, 0x70, 0x61, 0x74, 0x68, 0x22, 0xfd, 0x03, 0x0a, 0x10, 0x47, 0x65, 0x74, 0x4d, 0x6f, 0x64,
	0x75, 0x6c, 0x65, 0x43, 0x6f, 0x6e, 0x74, 0x65, 0x6e, 0x74, 0x1a, 0x2b, 0x0a, 0x04, 0x48, 0x69,
	0x6e, 0x74, 0x12, 0x23, 0x0a, 0x0d, 0x72, 0x65, 0x73, 0x6f, 0x75, 0x72, 0x63, 0x65, 0x5f, 0x74,
	0x79, 0x70, 0x65, 0x18, 0x01, 0x20, 0x01, 0x28, 0x09, 0x52, 0x0c, 0x72, 0x65, 0x73, 0x6f, 0x75,
	0x72, 0x63, 0x65, 0x54, 0x79, 0x70, 0x65, 0x1a, 0xba, 0x01, 0x0a, 0x06, 0x4f, 0x70, 0x74, 0x69,
	0x6f, 0x6e, 0x12, 0x33, 0x0a, 0x0a, 0x6d, 0x6f, 0x64, 0x75, 0x6c, 0x65, 0x5f, 0x63, 0x74, 0x78,
	0x18, 0x01, 0x20, 0x01, 0x28, 0x0e, 0x32, 0x14, 0x2e, 0x70, 0x72, 0x6f, 0x74, 0x6f, 0x2e, 0x4d,
	0x6f, 0x64, 0x75, 0x6c, 0x65, 0x43, 0x74, 0x78, 0x54, 0x79, 0x70, 0x65, 0x52, 0x09, 0x6d, 0x6f,
	0x64, 0x75, 0x6c, 0x65, 0x43, 0x74, 0x78, 0x12, 0x30, 0x0a, 0x04, 0x68, 0x69, 0x6e, 0x74, 0x18,
	0x02, 0x20, 0x01, 0x28, 0x0b, 0x32, 0x1c, 0x2e, 0x70, 0x72, 0x6f, 0x74, 0x6f, 0x2e, 0x47, 0x65,
	0x74, 0x4d, 0x6f, 0x64, 0x75, 0x6c, 0x65, 0x43, 0x6f, 0x6e, 0x74, 0x65, 0x6e, 0x74, 0x2e, 0x48,
	0x69, 0x6e, 0x74, 0x52, 0x04, 0x68, 0x69, 0x6e, 0x74, 0x12, 0x43, 0x0a, 0x0b, 0x65, 0x78, 0x70,
	0x61, 0x6e, 0x64, 0x5f, 0x6d, 0x6f, 0x64, 0x65, 0x18, 0x04, 0x20, 0x01, 0x28, 0x0e, 0x32, 0x22,
	0x2e, 0x70, 0x72, 0x6f, 0x74, 0x6f, 0x2e, 0x47, 0x65, 0x74, 0x4d, 0x6f, 0x64, 0x75, 0x6c, 0x65,
	0x43, 0x6f, 0x6e, 0x74, 0x65, 0x6e, 0x74, 0x2e, 0x45, 0x78, 0x70, 0x61, 0x6e, 0x64, 0x4d, 0x6f,
	0x64, 0x65, 0x52, 0x0a, 0x65, 0x78, 0x70, 0x61, 0x6e, 0x64, 0x4d, 0x6f, 0x64, 0x65, 0x4a, 0x04,
	0x08, 0x03, 0x10, 0x04, 0x1a, 0x6c, 0x0a, 0x07, 0x52, 0x65, 0x71, 0x75, 0x65, 0x73, 0x74, 0x12,
	0x29, 0x0a, 0x06, 0x73, 0x63, 0x68, 0x65, 0x6d, 0x61, 0x18, 0x01, 0x20, 0x01, 0x28, 0x0b, 0x32,
	0x11, 0x2e, 0x70, 0x72, 0x6f, 0x74, 0x6f, 0x2e, 0x42, 0x6f, 0x64, 0x79, 0x53, 0x63, 0x68, 0x65,
	0x6d, 0x61, 0x52, 0x06, 0x73, 0x63, 0x68, 0x65, 0x6d, 0x61, 0x12, 0x36, 0x0a, 0x06, 0x6f, 0x70,
	0x74, 0x69, 0x6f, 0x6e, 0x18, 0x02, 0x20, 0x01, 0x28, 0x0b, 0x32, 0x1e, 0x2e, 0x70, 0x72, 0x6f,
	0x74, 0x6f, 0x2e, 0x47, 0x65, 0x74, 0x4d, 0x6f, 0x64, 0x75, 0x6c, 0x65, 0x43, 0x6f, 0x6e, 0x74,
	0x65, 0x6e, 0x74, 0x2e, 0x4f, 0x70, 0x74, 0x69, 0x6f, 0x6e, 0x52, 0x06, 0x6f, 0x70, 0x74, 0x69,
	0x6f, 0x6e, 0x1a, 0x38, 0x0a, 0x08, 0x52, 0x65, 0x73, 0x70, 0x6f, 0x6e, 0x73, 0x65, 0x12, 0x2c,
	0x0a, 0x07, 0x63, 0x6f, 0x6e, 0x74, 0x65, 0x6e, 0x74, 0x18, 0x01, 0x20, 0x01, 0x28, 0x0b, 0x32,
	0x12, 0x2e, 0x70, 0x72, 0x6f, 0x74, 0x6f, 0x2e, 0x42, 0x6f, 0x64, 0x79, 0x43, 0x6f, 0x6e, 0x74,
	0x65, 0x6e, 0x74, 0x52, 0x07, 0x63, 0x6f, 0x6e, 0x74, 0x65, 0x6e, 0x74, 0x22, 0x57, 0x0a, 0x0a,
	0x45, 0x78, 0x70, 0x61, 0x6e, 0x64, 0x4d, 0x6f, 0x64, 0x65, 0x12, 0x1b, 0x0a, 0x17, 0x45, 0x58,
	0x50, 0x41, 0x4e, 0x44, 0x5f, 0x4d, 0x4f, 0x44, 0x45, 0x5f, 0x55, 0x4e, 0x53, 0x50, 0x45, 0x43,
	0x49, 0x46, 0x49, 0x45, 0x44, 0x10, 0x00, 0x12, 0x14, 0x0a, 0x10, 0x45, 0x58, 0x50, 0x41, 0x4e,
	0x44, 0x5f, 0x4d, 0x4f, 0x44, 0x45, 0x5f, 0x4e, 0x4f, 0x4e, 0x45, 0x10, 0x01, 0x12, 0x16, 0x0a,
	0x12, 0x45, 0x58, 0x50, 0x41, 0x4e, 0x44, 0x5f, 0x4d, 0x4f, 0x44, 0x45, 0x5f, 0x45, 0x58, 0x50,
	0x41, 0x4e, 0x44, 0x10, 0x02, 0x22, 0x48, 0x0a, 0x07, 0x47, 0x65, 0x74, 0x46, 0x69, 0x6c, 0x65,
	0x1a, 0x1d, 0x0a, 0x07, 0x52, 0x65, 0x71, 0x75, 0x65, 0x73, 0x74, 0x12, 0x12, 0x0a, 0x04, 0x6e,
	0x61, 0x6d, 0x65, 0x18, 0x01, 0x20, 0x01, 0x28, 0x09, 0x52, 0x04, 0x6e, 0x61, 0x6d, 0x65, 0x1a,
	0x1e, 0x0a, 0x08, 0x52, 0x65, 0x73, 0x70, 0x6f, 0x6e, 0x73, 0x65, 0x12, 0x12, 0x0a, 0x04, 0x66,
	0x69, 0x6c, 0x65, 0x18, 0x01, 0x20, 0x01, 0x28, 0x0c, 0x52, 0x04, 0x66, 0x69, 0x6c, 0x65, 0x22,
	0x96, 0x01, 0x0a, 0x08, 0x47, 0x65, 0x74, 0x46, 0x69, 0x6c, 0x65, 0x73, 0x1a, 0x09, 0x0a, 0x07,
	0x52, 0x65, 0x71, 0x75, 0x65, 0x73, 0x74, 0x1a, 0x7f, 0x0a, 0x08, 0x52, 0x65, 0x73, 0x70, 0x6f,
	0x6e, 0x73, 0x65, 0x12, 0x39, 0x0a, 0x05, 0x66, 0x69, 0x6c, 0x65, 0x73, 0x18, 0x01, 0x20, 0x03,
	0x28, 0x0b, 0x32, 0x23, 0x2e, 0x70, 0x72, 0x6f, 0x74, 0x6f, 0x2e, 0x47, 0x65, 0x74, 0x46, 0x69,
	0x6c, 0x65, 0x73, 0x2e, 0x52, 0x65, 0x73, 0x70, 0x6f, 0x6e, 0x73, 0x65, 0x2e, 0x46, 0x69, 0x6c,
	0x65, 0x73, 0x45, 0x6e, 0x74, 0x72, 0x79, 0x52, 0x05, 0x66, 0x69, 0x6c, 0x65, 0x73, 0x1a, 0x38,
	0x0a, 0x0a, 0x46, 0x69, 0x6c, 0x65, 0x73, 0x45, 0x6e, 0x74, 0x72, 0x79, 0x12, 0x10, 0x0a, 0x03,
	0x6b, 0x65, 0x79, 0x18, 0x01, 0x20, 0x01, 0x28, 0x09, 0x52, 0x03, 0x6b, 0x65, 0x79, 0x12, 0x14,
	0x0a, 0x05, 0x76, 0x61, 0x6c, 0x75, 0x65, 0x18, 0x02, 0x20, 0x01, 0x28, 0x0c, 0x52, 0x05, 0x76,
	0x61, 0x6c, 0x75, 0x65, 0x3a, 0x02, 0x38, 0x01, 0x22, 0x9a, 0x01, 0x0a, 0x14, 0x47, 0x65, 0x74,
	0x52, 0x75, 0x6c, 0x65, 0x43, 0x6f, 0x6e, 0x66, 0x69, 0x67, 0x43, 0x6f, 0x6e, 0x74, 0x65, 0x6e,
	0x74, 0x1a, 0x48, 0x0a, 0x07, 0x52, 0x65, 0x71, 0x75, 0x65, 0x73, 0x74, 0x12, 0x12, 0x0a, 0x04,
	0x6e, 0x61, 0x6d, 0x65, 0x18, 0x01, 0x20, 0x01, 0x28, 0x09, 0x52, 0x04, 0x6e, 0x61, 0x6d, 0x65,
	0x12, 0x29, 0x0a, 0x06, 0x73, 0x63, 0x68, 0x65, 0x6d, 0x61, 0x18, 0x02, 0x20, 0x01, 0x28, 0x0b,
	0x32, 0x11, 0x2e, 0x70, 0x72, 0x6f, 0x74, 0x6f, 0x2e, 0x42, 0x6f, 0x64, 0x79, 0x53, 0x63, 0x68,
	0x65, 0x6d, 0x61, 0x52, 0x06, 0x73, 0x63, 0x68, 0x65, 0x6d, 0x61, 0x1a, 0x38, 0x0a, 0x08, 0x52,
	0x65, 0x73, 0x70, 0x6f, 0x6e, 0x73, 0x65, 0x12, 0x2c, 0x0a, 0x07, 0x63, 0x6f, 0x6e, 0x74, 0x65,
	0x6e, 0x74, 0x18, 0x01, 0x20, 0x01, 0x28, 0x0b, 0x32, 0x12, 0x2e, 0x70, 0x72, 0x6f, 0x74, 0x6f,
	0x2e, 0x42, 0x6f, 0x64, 0x79, 0x43, 0x6f, 0x6e, 0x74, 0x65, 0x6e, 0x74, 0x52, 0x07, 0x63, 0x6f,
	0x6e, 0x74, 0x65, 0x6e, 0x74, 0x22, 0xa9, 0x02, 0x0a, 0x0c, 0x45, 0x76, 0x61, 0x6c, 0x75, 0x61,
	0x74, 0x65, 0x45, 0x78, 0x70, 0x72, 0x1a, 0x51, 0x0a, 0x06, 0x4f, 0x70, 0x74, 0x69, 0x6f, 0x6e,
	0x12, 0x12, 0x0a, 0x04, 0x74, 0x79, 0x70, 0x65, 0x18, 0x01, 0x20, 0x01, 0x28, 0x0c, 0x52, 0x04,
	0x74, 0x79, 0x70, 0x65, 0x12, 0x33, 0x0a, 0x0a, 0x6d, 0x6f, 0x64, 0x75, 0x6c, 0x65, 0x5f, 0x63,
	0x74, 0x78, 0x18, 0x02, 0x20, 0x01, 0x28, 0x0e, 0x32, 0x14, 0x2e, 0x70, 0x72, 0x6f, 0x74, 0x6f,
	0x2e, 0x4d, 0x6f, 0x64, 0x75, 0x6c, 0x65, 0x43, 0x74, 0x78, 0x54, 0x79, 0x70, 0x65, 0x52, 0x09,
	0x6d, 0x6f, 0x64, 0x75, 0x6c, 0x65, 0x43, 0x74, 0x78, 0x1a, 0x7c, 0x0a, 0x07, 0x52, 0x65, 0x71,
	0x75, 0x65, 0x73, 0x74, 0x12, 0x32, 0x0a, 0x06, 0x6f, 0x70, 0x74, 0x69, 0x6f, 0x6e, 0x18, 0x03,
	0x20, 0x01, 0x28, 0x0b, 0x32, 0x1a, 0x2e, 0x70, 0x72, 0x6f, 0x74, 0x6f, 0x2e, 0x45, 0x76, 0x61,
	0x6c, 0x75, 0x61, 0x74, 0x65, 0x45, 0x78, 0x70, 0x72, 0x2e, 0x4f, 0x70, 0x74, 0x69, 0x6f, 0x6e,
	0x52, 0x06, 0x6f, 0x70, 0x74, 0x69, 0x6f, 0x6e, 0x12, 0x31, 0x0a, 0x0a, 0x65, 0x78, 0x70, 0x72,
	0x65, 0x73, 0x73, 0x69, 0x6f, 0x6e, 0x18, 0x04, 0x20, 0x01, 0x28, 0x0b, 0x32, 0x11, 0x2e, 0x70,
	0x72, 0x6f, 0x74, 0x6f, 0x2e, 0x45, 0x78, 0x70, 0x72, 0x65, 0x73, 0x73, 0x69, 0x6f, 0x6e, 0x52,
	0x0a, 0x65, 0x78, 0x70, 0x72, 0x65, 0x73, 0x73, 0x69, 0x6f, 0x6e, 0x4a, 0x04, 0x08, 0x01, 0x10,
	0x02, 0x4a, 0x04, 0x08, 0x02, 0x10, 0x03, 0x1a, 0x48, 0x0a, 0x08, 0x52, 0x65, 0x73, 0x70, 0x6f,
	0x6e, 0x73, 0x65, 0x12, 0x14, 0x0a, 0x05, 0x76, 0x61, 0x6c, 0x75, 0x65, 0x18, 0x01, 0x20, 0x01,
	0x28, 0x0c, 0x52, 0x05, 0x76, 0x61, 0x6c, 0x75, 0x65, 0x12, 0x26, 0x0a, 0x05, 0x6d, 0x61, 0x72,
	0x6b, 0x73, 0x18, 0x02, 0x20, 0x03, 0x28, 0x0b, 0x32, 0x10, 0x2e, 0x70, 0x72, 0x6f, 0x74, 0x6f,
	0x2e, 0x56, 0x61, 0x6c, 0x75, 0x65, 0x4d, 0x61, 0x72, 0x6b, 0x52, 0x05, 0x6d, 0x61, 0x72, 0x6b,
	0x73, 0x22, 0xa6, 0x03, 0x0a, 0x09, 0x45, 0x6d, 0x69, 0x74, 0x49, 0x73, 0x73, 0x75, 0x65, 0x1a,
	0x7f, 0x0a, 0x04, 0x52, 0x75, 0x6c, 0x65, 0x12, 0x12, 0x0a, 0x04, 0x6e, 0x61, 0x6d, 0x65, 0x18,
	0x01, 0x20, 0x01, 0x28, 0x09, 0x52, 0x04, 0x6e, 0x61, 0x6d, 0x65, 0x12, 0x18, 0x0a, 0x07, 0x65,
	0x6e, 0x61, 0x62, 0x6c, 0x65, 0x64, 0x18, 0x02, 0x20, 0x01, 0x28, 0x08, 0x52, 0x07, 0x65, 0x6e,
	0x61, 0x62, 0x6c, 0x65, 0x64, 0x12, 0x35, 0x0a, 0x08, 0x73, 0x65, 0x76, 0x65, 0x72, 0x69, 0x74,
	0x79, 0x18, 0x03, 0x20, 0x01, 0x28, 0x0e, 0x32, 0x19, 0x2e, 0x70, 0x72, 0x6f, 0x74, 0x6f, 0x2e,
	0x45, 0x6d, 0x69, 0x74, 0x49, 0x73, 0x73, 0x75, 0x65, 0x2e, 0x53, 0x65, 0x76, 0x65, 0x72, 0x69,
	0x74, 0x79, 0x52, 0x08, 0x73, 0x65, 0x76, 0x65, 0x72, 0x69, 0x74, 0x79, 0x12, 0x12, 0x0a, 0x04,
	0x6c, 0x69, 0x6e, 0x6b, 0x18, 0x04, 0x20, 0x01, 0x28, 0x09, 0x52, 0x04, 0x6c, 0x69, 0x6e, 0x6b,
	0x1a, 0x8c, 0x01, 0x0a, 0x07, 0x52, 0x65, 0x71, 0x75, 0x65, 0x73, 0x74, 0x12, 0x29, 0x0a, 0x04,
	0x72, 0x75, 0x6c, 0x65, 0x18, 0x01, 0x20, 0x01, 0x28, 0x0b, 0x32, 0x15, 0x2e, 0x70, 0x72, 0x6f,
	0x74, 0x6f, 0x2e, 0x45, 0x6d, 0x69, 0x74, 0x49, 0x73, 0x73, 0x75, 0x65, 0x2e, 0x52, 0x75, 0x6c,
	0x65, 0x52, 0x04, 0x72, 0x75, 0x6c, 0x65, 0x12, 0x18, 0x0a, 0x07, 0x6d, 0x65, 0x73, 0x73, 0x61,
	0x67, 0x65, 0x18, 0x02, 0x20, 0x01, 0x28, 0x09, 0x52, 0x07, 0x6d, 0x65, 0x73, 0x73, 0x61, 0x67,
	0x65, 0x12, 0x22, 0x0a, 0x05, 0x72, 0x61, 0x6e, 0x67, 0x65, 0x18, 0x03, 0x20, 0x01, 0x28, 0x0b,
	0x32, 0x0c, 0x2e, 0x70, 0x72, 0x6f, 0x74, 0x6f, 0x2e, 0x52, 0x61, 0x6e, 0x67, 0x65, 0x52, 0x05,
	0x72, 0x61, 0x6e, 0x67, 0x65, 0x12, 0x18, 0x0a, 0x07, 0x66, 0x69, 0x78, 0x61, 0x62, 0x6c, 0x65,
	0x18, 0x04, 0x20, 0x01, 0x28, 0x08, 0x52, 0x07, 0x66, 0x69, 0x78, 0x61, 0x62, 0x6c, 0x65, 0x1a,
	0x24, 0x0a, 0x08, 0x52, 0x65, 0x73, 0x70, 0x6f, 0x6e, 0x73, 0x65, 0x12, 0x18, 0x0a, 0x07, 0x61,
	0x70, 0x70, 0x6c, 0x69, 0x65, 0x64, 0x18, 0x01, 0x20, 0x01, 0x28, 0x08, 0x52, 0x07, 0x61, 0x70,
	0x70, 0x6c, 0x69, 0x65, 0x64, 0x22, 0x63, 0x0a, 0x08, 0x53, 0x65, 0x76, 0x65, 0x72, 0x69, 0x74,
	0x79, 0x12, 0x18, 0x0a, 0x14, 0x53, 0x45, 0x56, 0x45, 0x52, 0x49, 0x54, 0x59, 0x5f, 0x55, 0x4e,
	0x53, 0x50, 0x45, 0x43, 0x49, 0x46, 0x49, 0x45, 0x44, 0x10, 0x00, 0x12, 0x12, 0x0a, 0x0e, 0x53,
	0x45, 0x56, 0x45, 0x52, 0x49, 0x54, 0x59, 0x5f, 0x45, 0x52, 0x52, 0x4f, 0x52, 0x10, 0x01, 0x12,
	0x14, 0x0a, 0x10, 0x53, 0x45, 0x56, 0x45, 0x52, 0x49, 0x54, 0x59, 0x5f, 0x57, 0x41, 0x52, 0x4e,
	0x49, 0x4e, 0x47, 0x10, 0x02, 0x12, 0x13, 0x0a, 0x0f, 0x53, 0x45, 0x56, 0x45, 0x52, 0x49, 0x54,
	0x59, 0x5f, 0x4e, 0x4f, 0x54, 0x49, 0x43, 0x45, 0x10, 0x03, 0x22, 0xa6, 0x01, 0x0a, 0x0c, 0x41,
	0x70, 0x70, 0x6c, 0x79, 0x43, 0x68, 0x61, 0x6e, 0x67, 0x65, 0x73, 0x1a, 0x89, 0x01, 0x0a, 0x07,
	0x52, 0x65, 0x71, 0x75, 0x65, 0x73, 0x74, 0x12, 0x42, 0x0a, 0x07, 0x63, 0x68, 0x61, 0x6e, 0x67,
	0x65, 0x73, 0x18, 0x01, 0x20, 0x03, 0x28, 0x0b, 0x32, 0x28, 0x2e, 0x70, 0x72, 0x6f, 0x74, 0x6f,
	0x2e, 0x41, 0x70, 0x70, 0x6c, 0x79, 0x43, 0x68, 0x61, 0x6e, 0x67, 0x65, 0x73, 0x2e, 0x52, 0x65,
	0x71, 0x75, 0x65, 0x73, 0x74, 0x2e, 0x43, 0x68, 0x61, 0x6e, 0x67, 0x65, 0x73, 0x45, 0x6e, 0x74,
	0x72, 0x79, 0x52, 0x07, 0x63, 0x68, 0x61, 0x6e, 0x67, 0x65, 0x73, 0x1a, 0x3a, 0x0a, 0x0c, 0x43,
	0x68, 0x61, 0x6e, 0x67, 0x65, 0x73, 0x45, 0x6e, 0x74, 0x72, 0x79, 0x12, 0x10, 0x0a, 0x03, 0x6b,
	0x65, 0x79, 0x18, 0x01, 0x20, 0x01, 0x28, 0x09, 0x52, 0x03, 0x6b, 0x65, 0x79, 0x12, 0x14, 0x0a,
	0x05, 0x76, 0x61, 0x6c, 0x75, 0x65, 0x18, 0x02, 0x20, 0x01, 0x28, 0x0c, 0x52, 0x05, 0x76, 0x61,
	0x6c, 0x75, 0x65, 0x3a, 0x02, 0x38, 0x01, 0x1a, 0x0a, 0x0a, 0x08, 0x52, 0x65, 0x73, 0x70, 0x6f,
	0x6e, 0x73, 0x65, 0x22, 0xc3, 0x02, 0x0a, 0x0a, 0x42, 0x6f, 0x64, 0x79, 0x53, 0x63, 0x68, 0x65,
	0x6d, 0x61, 0x12, 0x3b, 0x0a, 0x0a, 0x61, 0x74, 0x74, 0x72, 0x69, 0x62, 0x75, 0x74, 0x65, 0x73,
	0x18, 0x01, 0x20, 0x03, 0x28, 0x0b, 0x32, 0x1b, 0x2e, 0x70, 0x72, 0x6f, 0x74, 0x6f, 0x2e, 0x42,
	0x6f, 0x64, 0x79, 0x53, 0x63, 0x68, 0x65, 0x6d, 0x61, 0x2e, 0x41, 0x74, 0x74, 0x72, 0x69, 0x62,
	0x75, 0x74, 0x65, 0x52, 0x0a, 0x61, 0x74, 0x74, 0x72, 0x69, 0x62, 0x75, 0x74, 0x65, 0x73, 0x12,
	0x2f, 0x0a, 0x06, 0x62, 0x6c, 0x6f, 0x63, 0x6b, 0x73, 0x18, 0x02, 0x20, 0x03, 0x28, 0x0b, 0x32,
	0x17, 0x2e, 0x70, 0x72, 0x6f, 0x74, 0x6f, 0x2e, 0x42, 0x6f, 0x64, 0x79, 0x53, 0x63, 0x68, 0x65,
	0x6d, 0x61, 0x2e, 0x42, 0x6c, 0x6f, 0x63, 0x6b, 0x52, 0x06, 0x62, 0x6c, 0x6f, 0x63, 0x6b, 0x73,
	0x12, 0x25, 0x0a, 0x04, 0x4d, 0x6f, 0x64, 0x65, 0x18, 0x03, 0x20, 0x01, 0x28, 0x0e, 0x32, 0x11,
	0x2e, 0x70, 0x72, 0x6f, 0x74, 0x6f, 0x2e, 0x53, 0x63, 0x68, 0x65, 0x6d, 0x61, 0x4d, 0x6f, 0x64,
	0x65, 0x52, 0x04, 0x4d, 0x6f, 0x64, 0x65, 0x1a, 0x3b, 0x0a, 0x09, 0x41, 0x74, 0x74, 0x72, 0x69,
	0x62, 0x75, 0x74, 0x65, 0x12, 0x12, 0x0a, 0x04, 0x6e, 0x61, 0x6d, 0x65, 0x18, 0x01, 0x20, 0x01,
	0x28, 0x09, 0x52, 0x04, 0x6e, 0x61, 0x6d, 0x65, 0x12, 0x1a, 0x0a, 0x08, 0x72, 0x65, 0x71, 0x75,
	0x69, 0x72, 0x65, 0x64, 0x18, 0x02, 0x20, 0x01, 0x28, 0x08, 0x52, 0x08, 0x72, 0x65, 0x71, 0x75,
	0x69, 0x72, 0x65, 0x64, 0x1a, 0x63, 0x0a, 0x05, 0x42, 0x6c, 0x6f, 0x63, 0x6b, 0x12, 0x12, 0x0a,
	0x04, 0x74, 0x79, 0x70, 0x65, 0x18, 0x01, 0x20, 0x01, 0x28, 0x09, 0x52, 0x04, 0x74, 0x79, 0x70,
	0x65, 0x12, 0x1f, 0x0a, 0x0b, 0x6c, 0x61, 0x62, 0x65, 0x6c, 0x5f, 0x6e, 0x61, 0x6d, 0x65, 0x73,
	0x18, 0x02, 0x20, 0x03, 0x28, 0x09, 0x52, 0x0a, 0x6c, 0x61, 0x62, 0x65, 0x6c, 0x4e, 0x61, 0x6d,
	0x65, 0x73, 0x12, 0x25, 0x0a, 0x04, 0x62, 0x6f, 0x64, 0x79, 0x18, 0x03, 0x20, 0x01, 0x28, 0x0b,
	0x32, 0x11, 0x2e, 0x70, 0x72, 0x6f, 0x74, 0x6f, 0x2e, 0x42, 0x6f, 0x64, 0x79, 0x53, 0x63, 0x68,
	0x65, 0x6d, 0x61, 0x52, 0x04, 0x62, 0x6f, 0x64, 0x79, 0x22, 0xf9, 0x04, 0x0a, 0x0b, 0x42, 0x6f,
	0x64, 0x79, 0x43, 0x6f, 0x6e, 0x74, 0x65, 0x6e, 0x74, 0x12, 0x42, 0x0a, 0x0a, 0x61, 0x74, 0x74,
	0x72, 0x69, 0x62, 0x75, 0x74, 0x65, 0x73, 0x18, 0x01, 0x20, 0x03, 0x28, 0x0b, 0x32, 0x22, 0x2e,
	0x70, 0x72, 0x6f, 0x74, 0x6f, 0x2e, 0x42, 0x6f, 0x64, 0x79, 0x43, 0x6f, 0x6e, 0x74, 0x65, 0x6e,
	0x74, 0x2e, 0x41, 0x74, 0x74, 0x72, 0x69, 0x62, 0x75, 0x74, 0x65, 0x73, 0x45, 0x6e, 0x74, 0x72,
	0x79, 0x52, 0x0a, 0x61, 0x74, 0x74, 0x72, 0x69, 0x62, 0x75, 0x74, 0x65, 0x73, 0x12, 0x30, 0x0a,
	0x06, 0x62, 0x6c, 0x6f, 0x63, 0x6b, 0x73, 0x18, 0x02, 0x20, 0x03, 0x28, 0x0b, 0x32, 0x18, 0x2e,
	0x70, 0x72, 0x6f, 0x74, 0x6f, 0x2e, 0x42, 0x6f, 0x64, 0x79, 0x43, 0x6f, 0x6e, 0x74, 0x65, 0x6e,
	0x74, 0x2e, 0x42, 0x6c, 0x6f, 0x63, 0x6b, 0x52, 0x06, 0x62, 0x6c, 0x6f, 0x63, 0x6b, 0x73, 0x1a,
	0xaf, 0x01, 0x0a, 0x09, 0x41, 0x74, 0x74, 0x72, 0x69, 0x62, 0x75, 0x74, 0x65, 0x12, 0x12, 0x0a,
	0x04, 0x6e, 0x61, 0x6d, 0x65, 0x18, 0x01, 0x20, 0x01, 0x28, 0x09, 0x52, 0x04, 0x6e, 0x61, 0x6d,
	0x65, 0x12, 0x22, 0x0a, 0x05, 0x72, 0x61, 0x6e, 0x67, 0x65, 0x18, 0x04, 0x20, 0x01, 0x28, 0x0b,
	0x32, 0x0c, 0x2e, 0x70, 0x72, 0x6f, 0x74, 0x6f, 0x2e, 0x52, 0x61, 0x6e, 0x67, 0x65, 0x52, 0x05,
	0x72, 0x61, 0x6e, 0x67, 0x65, 0x12, 0x2b, 0x0a, 0x0a, 0x6e, 0x61, 0x6d, 0x65, 0x5f, 0x72, 0x61,
	0x6e, 0x67, 0x65, 0x18, 0x05, 0x20, 0x01, 0x28, 0x0b, 0x32, 0x0c, 0x2e, 0x70, 0x72, 0x6f, 0x74,
	0x6f, 0x2e, 0x52, 0x61, 0x6e, 0x67, 0x65, 0x52, 0x09, 0x6e, 0x61, 0x6d, 0x65, 0x52, 0x61, 0x6e,
	0x67, 0x65, 0x12, 0x31, 0x0a, 0x0a, 0x65, 0x78, 0x70, 0x72, 0x65, 0x73, 0x73, 0x69, 0x6f, 0x6e,
	0x18, 0x06, 0x20, 0x01, 0x28, 0x0b, 0x32, 0x11, 0x2e, 0x70, 0x72, 0x6f, 0x74, 0x6f, 0x2e, 0x45,
	0x78, 0x70, 0x72, 0x65, 0x73, 0x73, 0x69, 0x6f, 0x6e, 0x52, 0x0a, 0x65, 0x78, 0x70, 0x72, 0x65,
	0x73, 0x73, 0x69, 0x6f, 0x6e, 0x4a, 0x04, 0x08, 0x02, 0x10, 0x03, 0x4a, 0x04, 0x08, 0x03, 0x10,
	0x04, 0x1a, 0xe4, 0x01, 0x0a, 0x05, 0x42, 0x6c, 0x6f, 0x63, 0x6b, 0x12, 0x12, 0x0a, 0x04, 0x74,
	0x79, 0x70, 0x65, 0x18, 0x01, 0x20, 0x01, 0x28, 0x09, 0x52, 0x04, 0x74, 0x79, 0x70, 0x65, 0x12,
	0x16, 0x0a, 0x06, 0x6c, 0x61, 0x62, 0x65, 0x6c, 0x73, 0x18, 0x02, 0x20, 0x03, 0x28, 0x09, 0x52,
	0x06, 0x6c, 0x61, 0x62, 0x65, 0x6c, 0x73, 0x12, 0x26, 0x0a, 0x04, 0x62, 0x6f, 0x64, 0x79, 0x18,
	0x03, 0x20, 0x01, 0x28, 0x0b, 0x32, 0x12, 0x2e, 0x70, 0x72, 0x6f, 0x74, 0x6f, 0x2e, 0x42, 0x6f,
	0x64, 0x79, 0x43, 0x6f, 0x6e, 0x74, 0x65, 0x6e, 0x74, 0x52, 0x04, 0x62, 0x6f, 0x64, 0x79, 0x12,
	0x29, 0x0a, 0x09, 0x64, 0x65, 0x66, 0x5f, 0x72, 0x61, 0x6e, 0x67, 0x65, 0x18, 0x04, 0x20, 0x01,
	0x28, 0x0b, 0x32, 0x0c, 0x2e, 0x70, 0x72, 0x6f, 0x74, 0x6f, 0x2e, 0x52, 0x61, 0x6e, 0x67, 0x65,
	0x52, 0x08, 0x64, 0x65, 0x66, 0x52, 0x61, 0x6e, 0x67, 0x65, 0x12, 0x2b, 0x0a, 0x0a, 0x74, 0x79,
	0x70, 0x65, 0x5f, 0x72, 0x61, 0x6e, 0x67, 0x65, 0x18, 0x05, 0x20, 0x01, 0x28, 0x0b, 0x32, 0x0c,
	0x2e, 0x70, 0x72, 0x6f, 0x74, 0x6f, 0x2e, 0x52, 0x61, 0x6e, 0x67, 0x65, 0x52, 0x09, 0x74, 0x79,
	0x70, 0x65, 0x52, 0x61, 0x6e, 0x67, 0x65, 0x12, 0x2f, 0x0a, 0x0c, 0x6c, 0x61, 0x62, 0x65, 0x6c,
	0x5f, 0x72, 0x61, 0x6e, 0x67, 0x65, 0x73, 0x18, 0x06, 0x20, 0x03, 0x28, 0x0b, 0x32, 0x0c, 0x2e,
	0x70, 0x72, 0x6f, 0x74, 0x6f, 0x2e, 0x52, 0x61, 0x6e, 0x67, 0x65, 0x52, 0x0b, 0x6c, 0x61, 0x62,
	0x65, 0x6c, 0x52, 0x61, 0x6e, 0x67, 0x65, 0x73, 0x1a, 0x5b, 0x0a, 0x0f, 0x41, 0x74, 0x74, 0x72,
	0x69, 0x62, 0x75, 0x74, 0x65, 0x73, 0x45, 0x6e, 0x74, 0x72, 0x79, 0x12, 0x10, 0x0a, 0x03, 0x6b,
	0x65, 0x79, 0x18, 0x01, 0x20, 0x01, 0x28, 0x09, 0x52, 0x03, 0x6b, 0x65, 0x79, 0x12, 0x32, 0x0a,
	0x05, 0x76, 0x61, 0x6c, 0x75, 0x65, 0x18, 0x02, 0x20, 0x01, 0x28, 0x0b, 0x32, 0x1c, 0x2e, 0x70,
	0x72, 0x6f, 0x74, 0x6f, 0x2e, 0x42, 0x6f, 0x64, 0x79, 0x43, 0x6f, 0x6e, 0x74, 0x65, 0x6e, 0x74,
	0x2e, 0x41, 0x74, 0x74, 0x72, 0x69, 0x62, 0x75, 0x74, 0x65, 0x52, 0x05, 0x76, 0x61, 0x6c, 0x75,
	0x65, 0x3a, 0x02, 0x38, 0x01, 0x22, 0x8f, 0x01, 0x0a, 0x0a, 0x45, 0x78, 0x70, 0x72, 0x65, 0x73,
	0x73, 0x69, 0x6f, 0x6e, 0x12, 0x14, 0x0a, 0x05, 0x62, 0x79, 0x74, 0x65, 0x73, 0x18, 0x01, 0x20,
	0x01, 0x28, 0x0c, 0x52, 0x05, 0x62, 0x79, 0x74, 0x65, 0x73, 0x12, 0x22, 0x0a, 0x05, 0x72, 0x61,
	0x6e, 0x67, 0x65, 0x18, 0x02, 0x20, 0x01, 0x28, 0x0b, 0x32, 0x0c, 0x2e, 0x70, 0x72, 0x6f, 0x74,
	0x6f, 0x2e, 0x52, 0x61, 0x6e, 0x67, 0x65, 0x52, 0x05, 0x72, 0x61, 0x6e, 0x67, 0x65, 0x12, 0x14,
	0x0a, 0x05, 0x76, 0x61, 0x6c, 0x75, 0x65, 0x18, 0x03, 0x20, 0x01, 0x28, 0x0c, 0x52, 0x05, 0x76,
	0x61, 0x6c, 0x75, 0x65, 0x12, 0x31, 0x0a, 0x0b, 0x76, 0x61, 0x6c, 0x75, 0x65, 0x5f, 0x6d, 0x61,
	0x72, 0x6b, 0x73, 0x18, 0x04, 0x20, 0x03, 0x28, 0x0b, 0x32, 0x10, 0x2e, 0x70, 0x72, 0x6f, 0x74,
	0x6f, 0x2e, 0x56, 0x61, 0x6c, 0x75, 0x65, 0x4d, 0x61, 0x72, 0x6b, 0x52, 0x0a, 0x76, 0x61, 0x6c,
	0x75, 0x65, 0x4d, 0x61, 0x72, 0x6b, 0x73, 0x22, 0xb6, 0x01, 0x0a, 0x05, 0x52, 0x61, 0x6e, 0x67,
	0x65, 0x12, 0x1a, 0x0a, 0x08, 0x66, 0x69, 0x6c, 0x65, 0x6e, 0x61, 0x6d, 0x65, 0x18, 0x01, 0x20,
	0x01, 0x28, 0x09, 0x52, 0x08, 0x66, 0x69, 0x6c, 0x65, 0x6e, 0x61, 0x6d, 0x65, 0x12, 0x26, 0x0a,
	0x05, 0x73, 0x74, 0x61, 0x72, 0x74, 0x18, 0x02, 0x20, 0x01, 0x28, 0x0b, 0x32, 0x10, 0x2e, 0x70,
	0x72, 0x6f, 0x74, 0x6f, 0x2e, 0x52, 0x61, 0x6e, 0x67, 0x65, 0x2e, 0x50, 0x6f, 0x73, 0x52, 0x05,
	0x73, 0x74, 0x61, 0x72, 0x74, 0x12, 0x22, 0x0a, 0x03, 0x65, 0x6e, 0x64, 0x18, 0x03, 0x20, 0x01,
	0x28, 0x0b, 0x32, 0x10, 0x2e, 0x70, 0x72, 0x6f, 0x74, 0x6f, 0x2e, 0x52, 0x61, 0x6e, 0x67, 0x65,
	0x2e, 0x50, 0x6f, 0x73, 0x52, 0x03, 0x65, 0x6e, 0x64, 0x1a, 0x45, 0x0a, 0x03, 0x50, 0x6f, 0x73,
	0x12, 0x12, 0x0a, 0x04, 0x6c, 0x69, 0x6e, 0x65, 0x18, 0x01, 0x20, 0x01, 0x28, 0x03, 0x52, 0x04,
	0x6c, 0x69, 0x6e, 0x65, 0x12, 0x16, 0x0a, 0x06, 0x63, 0x6f, 0x6c, 0x75, 0x6d, 0x6e, 0x18, 0x02,
	0x20, 0x01, 0x28, 0x03, 0x52, 0x06, 0x63, 0x6f, 0x6c, 0x75, 0x6d, 0x6e, 0x12, 0x12, 0x0a, 0x04,
	0x62, 0x79, 0x74, 0x65, 0x18, 0x03, 0x20, 0x01, 0x28, 0x03, 0x52, 0x04, 0x62, 0x79, 0x74, 0x65,
	0x22, 0xd8, 0x01, 0x0a, 0x0d, 0x41, 0x74, 0x74, 0x72, 0x69, 0x62, 0x75, 0x74, 0x65, 0x50, 0x61,
	0x74, 0x68, 0x12, 0x2f, 0x0a, 0x05, 0x73, 0x74, 0x65, 0x70, 0x73, 0x18, 0x01, 0x20, 0x03, 0x28,
	0x0b, 0x32, 0x19, 0x2e, 0x70, 0x72, 0x6f, 0x74, 0x6f, 0x2e, 0x41, 0x74, 0x74, 0x72, 0x69, 0x62,
	0x75, 0x74, 0x65, 0x50, 0x61, 0x74, 0x68, 0x2e, 0x53, 0x74, 0x65, 0x70, 0x52, 0x05, 0x73, 0x74,
	0x65, 0x70, 0x73, 0x1a, 0x95, 0x01, 0x0a, 0x04, 0x53, 0x74, 0x65, 0x70, 0x12, 0x27, 0x0a, 0x0e,
	0x61, 0x74, 0x74, 0x72, 0x69, 0x62, 0x75, 0x74, 0x65, 0x5f, 0x6e, 0x61, 0x6d, 0x65, 0x18, 0x01,
	0x20, 0x01, 0x28, 0x09, 0x48, 0x00, 0x52, 0x0d, 0x61, 0x74, 0x74, 0x72, 0x69, 0x62, 0x75, 0x74,
	0x65, 0x4e, 0x61, 0x6d, 0x65, 0x12, 0x2e, 0x0a, 0x12, 0x65, 0x6c, 0x65, 0x6d, 0x65, 0x6e, 0x74,
	0x5f, 0x6b, 0x65, 0x79, 0x5f, 0x73, 0x74, 0x72, 0x69, 0x6e, 0x67, 0x18, 0x02, 0x20, 0x01, 0x28,
	0x09, 0x48, 0x00, 0x52, 0x10, 0x65, 0x6c, 0x65, 0x6d, 0x65, 0x6e, 0x74, 0x4b, 0x65, 0x79, 0x53,
	0x74, 0x72, 0x69, 0x6e, 0x67, 0x12, 0x28, 0x0a, 0x0f, 0x65, 0x6c, 0x65, 0x6d, 0x65, 0x6e, 0x74,
	0x5f, 0x6b, 0x65, 0x79, 0x5f, 0x69, 0x6e, 0x74, 0x18, 0x03, 0x20, 0x01, 0x28, 0x03, 0x48, 0x00,
	0x52, 0x0d, 0x65, 0x6c, 0x65, 0x6d, 0x65, 0x6e, 0x74, 0x4b, 0x65, 0x79, 0x49, 0x6e, 0x74, 0x42,
	0x0a, 0x0a, 0x08, 0x73, 0x65, 0x6c, 0x65, 0x63, 0x74, 0x6f, 0x72, 0x22, 0x71, 0x0a, 0x09, 0x56,
	0x61, 0x6c, 0x75, 0x65, 0x4d, 0x61, 0x72, 0x6b, 0x12, 0x28, 0x0a, 0x04, 0x70, 0x61, 0x74, 0x68,
	0x18, 0x01, 0x20, 0x01, 0x28, 0x0b, 0x32, 0x14, 0x2e, 0x70, 0x72, 0x6f, 0x74, 0x6f, 0x2e, 0x41,
	0x74, 0x74, 0x72, 0x69, 0x62, 0x75, 0x74, 0x65, 0x50, 0x61, 0x74, 0x68, 0x52, 0x04, 0x70, 0x61,
	0x74, 0x68, 0x12, 0x1c, 0x0a, 0x09, 0x73, 0x65, 0x6e, 0x73, 0x69, 0x74, 0x69, 0x76, 0x65, 0x18,
	0x02, 0x20, 0x01, 0x28, 0x08, 0x52, 0x09, 0x73, 0x65, 0x6e, 0x73, 0x69, 0x74, 0x69, 0x76, 0x65,
	0x12, 0x1c, 0x0a, 0x09, 0x65, 0x70, 0x68, 0x65, 0x6d, 0x65, 0x72, 0x61, 0x6c, 0x18, 0x03, 0x20,
	0x01, 0x28, 0x08, 0x52, 0x09, 0x65, 0x70, 0x68, 0x65, 0x6d, 0x65, 0x72, 0x61, 0x6c, 0x22, 0x4d,
	0x0a, 0x0b, 0x45, 0x72, 0x72, 0x6f, 0x72, 0x44, 0x65, 0x74, 0x61, 0x69, 0x6c, 0x12, 0x24, 0x0a,
	0x04, 0x63, 0x6f, 0x64, 0x65, 0x18, 0x01, 0x20, 0x01, 0x28, 0x0e, 0x32, 0x10, 0x2e, 0x70, 0x72,
	0x6f, 0x74, 0x6f, 0x2e, 0x45, 0x72, 0x72, 0x6f, 0x72, 0x43, 0x6f, 0x64, 0x65, 0x52, 0x04, 0x63,
	0x6f, 0x64, 0x65, 0x12, 0x18, 0x0a, 0x07, 0x6d, 0x65, 0x73, 0x73, 0x61, 0x67, 0x65, 0x18, 0x02,
	0x20, 0x01, 0x28, 0x09, 0x52, 0x07, 0x6d, 0x65, 0x73, 0x73, 0x61, 0x67, 0x65, 0x2a, 0x64, 0x0a,
	0x0d, 0x4d, 0x6f, 0x64, 0x75, 0x6c, 0x65, 0x43, 0x74, 0x78, 0x54, 0x79, 0x70, 0x65, 0x12, 0x1f,
	0x0a, 0x1b, 0x4d, 0x4f, 0x44, 0x55, 0x4c, 0x45, 0x5f, 0x43, 0x54, 0x58, 0x5f, 0x54, 0x59, 0x50,
	0x45, 0x5f, 0x55, 0x4e, 0x53, 0x50, 0x45, 0x43, 0x49, 0x46, 0x49, 0x45, 0x44, 0x10, 0x00, 0x12,
	0x18, 0x0a, 0x14, 0x4d, 0x4f, 0x44, 0x55, 0x4c, 0x45, 0x5f, 0x43, 0x54, 0x58, 0x5f, 0x54, 0x59,
	0x50, 0x45, 0x5f, 0x53, 0x45, 0x4c, 0x46, 0x10, 0x01, 0x12, 0x18, 0x0a, 0x14, 0x4d, 0x4f, 0x44,
	0x55, 0x4c, 0x45, 0x5f, 0x43, 0x54, 0x58, 0x5f, 0x54, 0x59, 0x50, 0x45, 0x5f, 0x52, 0x4f, 0x4f,
	0x54, 0x10, 0x02, 0x2a, 0x63, 0x0a, 0x0a, 0x53, 0x63, 0x68, 0x65, 0x6d, 0x61, 0x4d, 0x6f, 0x64,
	0x65, 0x12, 0x1b, 0x0a, 0x17, 0x53, 0x43, 0x48, 0x45, 0x4d, 0x41, 0x5f, 0x4d, 0x4f, 0x44, 0x45,
	0x5f, 0x55, 0x4e, 0x53, 0x50, 0x45, 0x43, 0x49, 0x46, 0x49, 0x45, 0x44, 0x10, 0x00, 0x12, 0x17,
	0x0a, 0x13, 0x53, 0x43, 0x48, 0x45, 0x4d, 0x41, 0x5f, 0x4d, 0x4f, 0x44, 0x45, 0x5f, 0x44, 0x45,
	0x46, 0x41, 0x55, 0x4c, 0x54, 0x10, 0x01, 0x12, 0x1f, 0x0a, 0x1b, 0x53, 0x43, 0x48, 0x45, 0x4d,
	0x41, 0x5f, 0x4d, 0x4f, 0x44, 0x45, 0x5f, 0x4a, 0x55, 0x53, 0x54, 0x5f, 0x41, 0x54, 0x54, 0x52,
	0x49, 0x42, 0x55, 0x54, 0x45, 0x53, 0x10, 0x02, 0x2a, 0x53, 0x0a, 0x09, 0x45, 0x72, 0x72, 0x6f,
	0x72, 0x43, 0x6f, 0x64, 0x65, 0x12, 0x1a, 0x0a, 0x16, 0x45, 0x52, 0x52, 0x4f, 0x52, 0x5f, 0x43,
	0x4f, 0x44, 0x45, 0x5f, 0x55, 0x4e, 0x53, 0x50, 0x45, 0x43, 0x49, 0x46, 0x49, 0x45, 0x44, 0x10,
	0x00, 0x12, 0x18, 0x0a, 0x14, 0x45, 0x52, 0x52, 0x4f, 0x52, 0x5f, 0x43, 0x4f, 0x44, 0x45, 0x5f,
	0x53, 0x45, 0x4e, 0x53, 0x49, 0x54, 0x49, 0x56, 0x45, 0x10, 0x04, 0x22, 0x04, 0x08, 0x01, 0x10,
	0x01, 0x22, 0x04, 0x08, 0x02, 0x10, 0x02, 0x22, 0x04, 0x08, 0x03, 0x10, 0x03, 0x32, 0xb2, 0x05,
	0x0a, 0x07, 0x52, 0x75, 0x6c, 0x65, 0x53, 0x65, 0x74, 0x12, 0x3a, 0x0a, 0x07, 0x47, 0x65, 0x74,
	0x4e, 0x61, 0x6d, 0x65, 0x12, 0x16, 0x2e, 0x70, 0x72, 0x6f, 0x74, 0x6f, 0x2e, 0x47, 0x65, 0x74,
	0x4e, 0x61, 0x6d, 0x65, 0x2e, 0x52, 0x65, 0x71, 0x75, 0x65, 0x73, 0x74, 0x1a, 0x17, 0x2e, 0x70,
	0x72, 0x6f, 0x74, 0x6f, 0x2e, 0x47, 0x65, 0x74, 0x4e, 0x61, 0x6d, 0x65, 0x2e, 0x52, 0x65, 0x73,
	0x70, 0x6f, 0x6e, 0x73, 0x65, 0x12, 0x43, 0x0a, 0x0a, 0x47, 0x65, 0x74, 0x56, 0x65, 0x72, 0x73,
	0x69, 0x6f, 0x6e, 0x12, 0x19, 0x2e, 0x70, 0x72, 0x6f, 0x74, 0x6f, 0x2e, 0x47, 0x65, 0x74, 0x56,
	0x65, 0x72, 0x73, 0x69, 0x6f, 0x6e, 0x2e, 0x52, 0x65, 0x71, 0x75, 0x65, 0x73, 0x74, 0x1a, 0x1a,
	0x2e, 0x70, 0x72, 0x6f, 0x74, 0x6f, 0x2e, 0x47, 0x65, 0x74, 0x56, 0x65, 0x72, 0x73, 0x69, 0x6f,
	0x6e, 0x2e, 0x52, 0x65, 0x73, 0x70, 0x6f, 0x6e, 0x73, 0x65, 0x12, 0x61, 0x0a, 0x14, 0x47, 0x65,
	0x74, 0x56, 0x65, 0x72, 0x73, 0x69, 0x6f, 0x6e, 0x43, 0x6f, 0x6e, 0x73, 0x74, 0x72, 0x61, 0x69,
	0x6e, 0x74, 0x12, 0x23, 0x2e, 0x70, 0x72, 0x6f, 0x74, 0x6f, 0x2e, 0x47, 0x65, 0x74, 0x56, 0x65,
	0x72, 0x73, 0x69, 0x6f, 0x6e, 0x43, 0x6f, 0x6e, 0x73, 0x74, 0x72, 0x61, 0x69, 0x6e, 0x74, 0x2e,
	0x52, 0x65, 0x71, 0x75, 0x65, 0x73, 0x74, 0x1a, 0x24, 0x2e, 0x70, 0x72, 0x6f, 0x74, 0x6f, 0x2e,
	0x47, 0x65, 0x74, 0x56, 0x65, 0x72, 0x73, 0x69, 0x6f, 0x6e, 0x43, 0x6f, 0x6e, 0x73, 0x74, 0x72,
	0x61, 0x69, 0x6e, 0x74, 0x2e, 0x52, 0x65, 0x73, 0x70, 0x6f, 0x6e, 0x73, 0x65, 0x12, 0x4c, 0x0a,
	0x0d, 0x47, 0x65, 0x74, 0x53, 0x44, 0x4b, 0x56, 0x65, 0x72, 0x73, 0x69, 0x6f, 0x6e, 0x12, 0x1c,
	0x2e, 0x70, 0x72, 0x6f, 0x74, 0x6f, 0x2e, 0x47, 0x65, 0x74, 0x53, 0x44, 0x4b, 0x56, 0x65, 0x72,
	0x73, 0x69, 0x6f, 0x6e, 0x2e, 0x52, 0x65, 0x71, 0x75, 0x65, 0x73, 0x74, 0x1a, 0x1d, 0x2e, 0x70,
	0x72, 0x6f, 0x74, 0x6f, 0x2e, 0x47, 0x65, 0x74, 0x53, 0x44, 0x4b, 0x56, 0x65, 0x72, 0x73, 0x69,
	0x6f, 0x6e, 0x2e, 0x52, 0x65, 0x73, 0x70, 0x6f, 0x6e, 0x73, 0x65, 0x12, 0x49, 0x0a, 0x0c, 0x47,
	0x65, 0x74, 0x52, 0x75, 0x6c, 0x65, 0x4e, 0x61, 0x6d, 0x65, 0x73, 0x12, 0x1b, 0x2e, 0x70, 0x72,
	0x6f, 0x74, 0x6f, 0x2e, 0x47, 0x65, 0x74, 0x52, 0x75, 0x6c, 0x65, 0x4e, 0x61, 0x6d, 0x65, 0x73,
	0x2e, 0x52, 0x65, 0x71, 0x75, 0x65, 0x73, 0x74, 0x1a, 0x1c, 0x2e, 0x70, 0x72, 0x6f, 0x74, 0x6f,
	0x2e, 0x47, 0x65, 0x74, 0x52, 0x75, 0x6c, 0x65, 0x4e, 0x61, 0x6d, 0x65, 0x73, 0x2e, 0x52, 0x65,
	0x73, 0x70, 0x6f, 0x6e, 0x73, 0x65, 0x12, 0x52, 0x0a, 0x0f, 0x47, 0x65, 0x74, 0x43, 0x6f, 0x6e,
	0x66, 0x69, 0x67, 0x53, 0x63, 0x68, 0x65, 0x6d, 0x61, 0x12, 0x1e, 0x2e, 0x70, 0x72, 0x6f, 0x74,
	0x6f, 0x2e, 0x47, 0x65, 0x74, 0x43, 0x6f, 0x6e, 0x66, 0x69, 0x67, 0x53, 0x63, 0x68, 0x65, 0x6d,
	0x61, 0x2e, 0x52, 0x65, 0x71, 0x75, 0x65, 0x73, 0x74, 0x1a, 0x1f, 0x2e, 0x70, 0x72, 0x6f, 0x74,
	0x6f, 0x2e, 0x47, 0x65, 0x74, 0x43, 0x6f, 0x6e, 0x66, 0x69, 0x67, 0x53, 0x63, 0x68, 0x65, 0x6d,
	0x61, 0x2e, 0x52, 0x65, 0x73, 0x70, 0x6f, 0x6e, 0x73, 0x65, 0x12, 0x58, 0x0a, 0x11, 0x41, 0x70,
	0x70, 0x6c, 0x79, 0x47, 0x6c, 0x6f, 0x62, 0x61, 0x6c, 0x43, 0x6f, 0x6e, 0x66, 0x69, 0x67, 0x12,
	0x20, 0x2e, 0x70, 0x72, 0x6f, 0x74, 0x6f, 0x2e, 0x41, 0x70, 0x70, 0x6c, 0x79, 0x47, 0x6c, 0x6f,
	0x62, 0x61, 0x6c, 0x43, 0x6f, 0x6e, 0x66, 0x69, 0x67, 0x2e, 0x52, 0x65, 0x71, 0x75, 0x65, 0x73,
	0x74, 0x1a, 0x21, 0x2e, 0x70, 0x72, 0x6f, 0x74, 0x6f, 0x2e, 0x41, 0x70, 0x70, 0x6c, 0x79, 0x47,
	0x6c, 0x6f, 0x62, 0x61, 0x6c, 0x43, 0x6f, 0x6e, 0x66, 0x69, 0x67, 0x2e, 0x52, 0x65, 0x73, 0x70,
	0x6f, 0x6e, 0x73, 0x65, 0x12, 0x46, 0x0a, 0x0b, 0x41, 0x70, 0x70, 0x6c, 0x79, 0x43, 0x6f, 0x6e,
	0x66, 0x69, 0x67, 0x12, 0x1a, 0x2e, 0x70, 0x72, 0x6f, 0x74, 0x6f, 0x2e, 0x41, 0x70, 0x70, 0x6c,
	0x79, 0x43, 0x6f, 0x6e, 0x66, 0x69, 0x67, 0x2e, 0x52, 0x65, 0x71, 0x75, 0x65, 0x73, 0x74, 0x1a,
	0x1b, 0x2e, 0x70, 0x72, 0x6f, 0x74, 0x6f, 0x2e, 0x41, 0x70, 0x70, 0x6c, 0x79, 0x43, 0x6f, 0x6e,
	0x66, 0x69, 0x67, 0x2e, 0x52, 0x65, 0x73, 0x70, 0x6f, 0x6e, 0x73, 0x65, 0x12, 0x34, 0x0a, 0x05,
	0x43, 0x68, 0x65, 0x63, 0x6b, 0x12, 0x14, 0x2e, 0x70, 0x72, 0x6f, 0x74, 0x6f, 0x2e, 0x43, 0x68,
	0x65, 0x63, 0x6b, 0x2e, 0x52, 0x65, 0x71, 0x75, 0x65, 0x73, 0x74, 0x1a, 0x15, 0x2e, 0x70, 0x72,
	0x6f, 0x74, 0x6f, 0x2e, 0x43, 0x68, 0x65, 0x63, 0x6b, 0x2e, 0x52, 0x65, 0x73, 0x70, 0x6f, 0x6e,
	0x73, 0x65, 0x32, 0xb1, 0x05, 0x0a, 0x06, 0x52, 0x75, 0x6e, 0x6e, 0x65, 0x72, 0x12, 0x4c, 0x0a,
	0x0d, 0x47, 0x65, 0x74, 0x4f, 0x72, 0x69, 0x67, 0x69, 0x6e, 0x61, 0x6c, 0x77, 0x64, 0x12, 0x1c,
	0x2e, 0x70, 0x72, 0x6f, 0x74, 0x6f, 0x2e, 0x47, 0x65, 0x74, 0x4f, 0x72, 0x69, 0x67, 0x69, 0x6e,
	0x61, 0x6c, 0x77, 0x64, 0x2e, 0x52, 0x65, 0x71, 0x75, 0x65, 0x73, 0x74, 0x1a, 0x1d, 0x2e, 0x70,
	0x72, 0x6f, 0x74, 0x6f, 0x2e, 0x47, 0x65, 0x74, 0x4f, 0x72, 0x69, 0x67, 0x69, 0x6e, 0x61, 0x6c,
	0x77, 0x64, 0x2e, 0x52, 0x65, 0x73, 0x70, 0x6f, 0x6e, 0x73, 0x65, 0x12, 0x4c, 0x0a, 0x0d, 0x47,
	0x65, 0x74, 0x4d, 0x6f, 0x64, 0x75, 0x6c, 0x65, 0x50, 0x61, 0x74, 0x68, 0x12, 0x1c, 0x2e, 0x70,
	0x72, 0x6f, 0x74, 0x6f, 0x2e, 0x47, 0x65, 0x74, 0x4d, 0x6f, 0x64, 0x75, 0x6c, 0x65, 0x50, 0x61,
	0x74, 0x68, 0x2e, 0x52, 0x65, 0x71, 0x75, 0x65, 0x73, 0x74, 0x1a, 0x1d, 0x2e, 0x70, 0x72, 0x6f,
	0x74, 0x6f, 0x2e, 0x47, 0x65, 0x74, 0x4d, 0x6f, 0x64, 0x75, 0x6c, 0x65, 0x50, 0x61, 0x74, 0x68,
	0x2e, 0x52, 0x65, 0x73, 0x70, 0x6f, 0x6e, 0x73, 0x65, 0x12, 0x55, 0x0a, 0x10, 0x47, 0x65, 0x74,
	0x4d, 0x6f, 0x64, 0x75, 0x6c, 0x65, 0x43, 0x6f, 0x6e, 0x74, 0x65, 0x6e, 0x74, 0x12, 0x1f, 0x2e,
	0x70, 0x72, 0x6f, 0x74, 0x6f, 0x2e, 0x47, 0x65, 0x74, 0x4d, 0x6f, 0x64, 0x75, 0x6c, 0x65, 0x43,
	0x6f, 0x6e, 0x74, 0x65, 0x6e, 0x74, 0x2e, 0x52, 0x65, 0x71, 0x75, 0x65, 0x73, 0x74, 0x1a, 0x20,
	0x2e, 0x70, 0x72, 0x6f, 0x74, 0x6f, 0x2e, 0x47, 0x65, 0x74, 0x4d, 0x6f, 0x64, 0x75, 0x6c, 0x65,
	0x43, 0x6f, 0x6e, 0x74, 0x65, 0x6e, 0x74, 0x2e, 0x52, 0x65, 0x73, 0x70, 0x6f, 0x6e, 0x73, 0x65,
	0x12, 0x3a, 0x0a, 0x07, 0x47, 0x65, 0x74, 0x46, 0x69, 0x6c, 0x65, 0x12, 0x16, 0x2e, 0x70, 0x72,
	0x6f, 0x74, 0x6f, 0x2e, 0x47, 0x65, 0x74, 0x46, 0x69, 0x6c, 0x65, 0x2e, 0x52, 0x65, 0x71, 0x75,
	0x65, 0x73, 0x74, 0x1a, 0x17, 0x2e, 0x70, 0x72, 0x6f, 0x74, 0x6f, 0x2e, 0x47, 0x65, 0x74, 0x46,
	0x69, 0x6c, 0x65, 0x2e, 0x52, 0x65, 0x73, 0x70, 0x6f, 0x6e, 0x73, 0x65, 0x12, 0x3d, 0x0a, 0x08,
	0x47, 0x65, 0x74, 0x46, 0x69, 0x6c, 0x65, 0x73, 0x12, 0x17, 0x2e, 0x70, 0x72, 0x6f, 0x74, 0x6f,
	0x2e, 0x47, 0x65, 0x74, 0x46, 0x69, 0x6c, 0x65, 0x73, 0x2e, 0x52, 0x65, 0x71, 0x75, 0x65, 0x73,
	0x74, 0x1a, 0x18, 0x2e, 0x70, 0x72, 0x6f, 0x74, 0x6f, 0x2e, 0x47, 0x65, 0x74, 0x46, 0x69, 0x6c,
	0x65, 0x73, 0x2e, 0x52, 0x65, 0x73, 0x70, 0x6f, 0x6e, 0x73, 0x65, 0x12, 0x61, 0x0a, 0x14, 0x47,
	0x65, 0x74, 0x52, 0x75, 0x6c, 0x65, 0x43, 0x6f, 0x6e, 0x66, 0x69, 0x67, 0x43, 0x6f, 0x6e, 0x74,
	0x65, 0x6e, 0x74, 0x12, 0x23, 0x2e, 0x70, 0x72, 0x6f, 0x74, 0x6f, 0x2e, 0x47, 0x65, 0x74, 0x52,
	0x75, 0x6c, 0x65, 0x43, 0x6f, 0x6e, 0x66, 0x69, 0x67, 0x43, 0x6f, 0x6e, 0x74, 0x65, 0x6e, 0x74,
	0x2e, 0x52, 0x65, 0x71, 0x75, 0x65, 0x73, 0x74, 0x1a, 0x24, 0x2e, 0x70, 0x72, 0x6f, 0x74, 0x6f,
	0x2e, 0x47, 0x65, 0x74, 0x52, 0x75, 0x6c, 0x65, 0x43, 0x6f, 0x6e, 0x66, 0x69, 0x67, 0x43, 0x6f,
	0x6e, 0x74, 0x65, 0x6e, 0x74, 0x2e, 0x52, 0x65, 0x73, 0x70, 0x6f, 0x6e, 0x73, 0x65, 0x12, 0x49,
	0x0a, 0x0c, 0x45, 0x76, 0x61, 0x6c, 0x75, 0x61, 0x74, 0x65, 0x45, 0x78, 0x70, 0x72, 0x12, 0x1b,
	0x2e, 0x70, 0x72, 0x6f, 0x74, 0x6f, 0x2e, 0x45, 0x76, 0x61, 0x6c, 0x75, 0x61, 0x74, 0x65, 0x45,
	0x78, 0x70, 0x72, 0x2e, 0x52, 0x65, 0x71, 0x75, 0x65, 0x73, 0x74, 0x1a, 0x1c, 0x2e, 0x70, 0x72,
	0x6f, 0x74, 0x6f, 0x2e, 0x45, 0x76, 0x61, 0x6c, 0x75, 0x61, 0x74, 0x65, 0x45, 0x78, 0x70, 0x72,
	0x2e, 0x52, 0x65, 0x73, 0x70, 0x6f, 0x6e, 0x73, 0x65, 0x12, 0x40, 0x0a, 0x09, 0x45, 0x6d, 0x69,
	0x74, 0x49, 0x73, 0x73, 0x75, 0x65, 0x12, 0x18, 0x2e, 0x70, 0x72, 0x6f, 0x74, 0x6f, 0x2e, 0x45,
	0x6d, 0x69, 0x74, 0x49, 0x73, 0x73, 0x75, 0x65, 0x2e, 0x52, 0x65, 0x71, 0x75, 0x65, 0x73, 0x74,
	0x1a, 0x19, 0x2e, 0x70, 0x72, 0x6f, 0x74, 0x6f, 0x2e, 0x45, 0x6d, 0x69, 0x74, 0x49, 0x73, 0x73,
	0x75, 0x65, 0x2e, 0x52, 0x65, 0x73, 0x70, 0x6f, 0x6e, 0x73, 0x65, 0x12, 0x49, 0x0a, 0x0c, 0x41,
	0x70, 0x70, 0x6c, 0x79, 0x43, 0x68, 0x61, 0x6e, 0x67, 0x65, 0x73, 0x12, 0x1b, 0x2e, 0x70, 0x72,
	0x6f, 0x74, 0x6f, 0x2e, 0x41, 0x70, 0x70, 0x6c, 0x79, 0x43, 0x68, 0x61, 0x6e, 0x67, 0x65, 0x73,
	0x2e, 0x52, 0x65, 0x71, 0x75, 0x65, 0x73, 0x74, 0x1a, 0x1c, 0x2e, 0x70, 0x72, 0x6f, 0x74, 0x6f,
	0x2e, 0x41, 0x70, 0x70, 0x6c, 0x79, 0x43, 0x68, 0x61, 0x6e, 0x67, 0x65, 0x73, 0x2e, 0x52, 0x65,
	0x73, 0x70, 0x6f, 0x6e, 0x73, 0x65, 0x42, 0x46, 0x5a, 0x44, 0x67, 0x69, 0x74, 0x68, 0x75, 0x62,
	0x2e, 0x63, 0x6f, 0x6d, 0x2f, 0x74, 0x65, 0x72, 0x72, 0x61, 0x66, 0x6f, 0x72, 0x6d, 0x2d, 0x6c,
	0x69, 0x6e, 0x74, 0x65, 0x72, 0x73, 0x2f, 0x74, 0x66, 0x6c, 0x69, 0x6e, 0x74, 0x2d, 0x70, 0x6c,
	0x75, 0x67, 0x69, 0x6e, 0x2d, 0x73, 0x64, 0x6b, 0x2f, 0x70, 0x6c, 0x75, 0x67, 0x69, 0x6e, 0x2f,
	0x69, 0x6e, 0x74, 0x65, 0x72, 0x6e, 0x61, 0x6c, 0x2f, 0x70, 0x72, 0x6f, 0x74, 0x6f, 0x62, 0x06,
	0x70, 0x72, 0x6f, 0x74, 0x6f, 0x33,
}

var (
	file_tflint_proto_rawDescOnce sync.Once
	file_tflint_proto_rawDescData = file_tflint_proto_rawDesc
)

func file_tflint_proto_rawDescGZIP() []byte {
	file_tflint_proto_rawDescOnce.Do(func() {
		file_tflint_proto_rawDescData = protoimpl.X.CompressGZIP(file_tflint_proto_rawDescData)
	})
	return file_tflint_proto_rawDescData
}

var file_tflint_proto_enumTypes = make([]protoimpl.EnumInfo, 5)
var file_tflint_proto_msgTypes = make([]protoimpl.MessageInfo, 77)
var file_tflint_proto_goTypes = []any{
	(ModuleCtxType)(0),                    // 0: proto.ModuleCtxType
	(SchemaMode)(0),                       // 1: proto.SchemaMode
	(ErrorCode)(0),                        // 2: proto.ErrorCode
	(GetModuleContent_ExpandMode)(0),      // 3: proto.GetModuleContent.ExpandMode
	(EmitIssue_Severity)(0),               // 4: proto.EmitIssue.Severity
	(*GetName)(nil),                       // 5: proto.GetName
	(*GetVersion)(nil),                    // 6: proto.GetVersion
	(*GetVersionConstraint)(nil),          // 7: proto.GetVersionConstraint
	(*GetSDKVersion)(nil),                 // 8: proto.GetSDKVersion
	(*GetRuleNames)(nil),                  // 9: proto.GetRuleNames
	(*GetConfigSchema)(nil),               // 10: proto.GetConfigSchema
	(*ApplyGlobalConfig)(nil),             // 11: proto.ApplyGlobalConfig
	(*ApplyConfig)(nil),                   // 12: proto.ApplyConfig
	(*Check)(nil),                         // 13: proto.Check
	(*GetOriginalwd)(nil),                 // 14: proto.GetOriginalwd
	(*GetModulePath)(nil),                 // 15: proto.GetModulePath
	(*GetModuleContent)(nil),              // 16: proto.GetModuleContent
	(*GetFile)(nil),                       // 17: proto.GetFile
	(*GetFiles)(nil),                      // 18: proto.GetFiles
	(*GetRuleConfigContent)(nil),          // 19: proto.GetRuleConfigContent
	(*EvaluateExpr)(nil),                  // 20: proto.EvaluateExpr
	(*EmitIssue)(nil),                     // 21: proto.EmitIssue
	(*ApplyChanges)(nil),                  // 22: proto.ApplyChanges
	(*BodySchema)(nil),                    // 23: proto.BodySchema
	(*BodyContent)(nil),                   // 24: proto.BodyContent
	(*Expression)(nil),                    // 25: proto.Expression
	(*Range)(nil),                         // 26: proto.Range
	(*AttributePath)(nil),                 // 27: proto.AttributePath
	(*ValueMark)(nil),                     // 28: proto.ValueMark
	(*ErrorDetail)(nil),                   // 29: proto.ErrorDetail
	(*GetName_Request)(nil),               // 30: proto.GetName.Request
	(*GetName_Response)(nil),              // 31: proto.GetName.Response
	(*GetVersion_Request)(nil),            // 32: proto.GetVersion.Request
	(*GetVersion_Response)(nil),           // 33: proto.GetVersion.Response
	(*GetVersionConstraint_Request)(nil),  // 34: proto.GetVersionConstraint.Request
	(*GetVersionConstraint_Response)(nil), // 35: proto.GetVersionConstraint.Response
	(*GetSDKVersion_Request)(nil),         // 36: proto.GetSDKVersion.Request
	(*GetSDKVersion_Response)(nil),        // 37: proto.GetSDKVersion.Response
	(*GetRuleNames_Request)(nil),          // 38: proto.GetRuleNames.Request
	(*GetRuleNames_Response)(nil),         // 39: proto.GetRuleNames.Response
	(*GetConfigSchema_Request)(nil),       // 40: proto.GetConfigSchema.Request
	(*GetConfigSchema_Response)(nil),      // 41: proto.GetConfigSchema.Response
	(*ApplyGlobalConfig_Config)(nil),      // 42: proto.ApplyGlobalConfig.Config
	(*ApplyGlobalConfig_RuleConfig)(nil),  // 43: proto.ApplyGlobalConfig.RuleConfig
	(*ApplyGlobalConfig_Request)(nil),     // 44: proto.ApplyGlobalConfig.Request
	(*ApplyGlobalConfig_Response)(nil),    // 45: proto.ApplyGlobalConfig.Response
	nil,                                   // 46: proto.ApplyGlobalConfig.Config.RulesEntry
	(*ApplyConfig_Request)(nil),           // 47: proto.ApplyConfig.Request
	(*ApplyConfig_Response)(nil),          // 48: proto.ApplyConfig.Response
	(*Check_Request)(nil),                 // 49: proto.Check.Request
	(*Check_Response)(nil),                // 50: proto.Check.Response
	(*GetOriginalwd_Request)(nil),         // 51: proto.GetOriginalwd.Request
	(*GetOriginalwd_Response)(nil),        // 52: proto.GetOriginalwd.Response
	(*GetModulePath_Request)(nil),         // 53: proto.GetModulePath.Request
	(*GetModulePath_Response)(nil),        // 54: proto.GetModulePath.Response
	(*GetModuleContent_Hint)(nil),         // 55: proto.GetModuleContent.Hint
	(*GetModuleContent_Option)(nil),       // 56: proto.GetModuleContent.Option
	(*GetModuleContent_Request)(nil),      // 57: proto.GetModuleContent.Request
	(*GetModuleContent_Response)(nil),     // 58: proto.GetModuleContent.Response
	(*GetFile_Request)(nil),               // 59: proto.GetFile.Request
	(*GetFile_Response)(nil),              // 60: proto.GetFile.Response
	(*GetFiles_Request)(nil),              // 61: proto.GetFiles.Request
	(*GetFiles_Response)(nil),             // 62: proto.GetFiles.Response
	nil,                                   // 63: proto.GetFiles.Response.FilesEntry
	(*GetRuleConfigContent_Request)(nil),  // 64: proto.GetRuleConfigContent.Request
	(*GetRuleConfigContent_Response)(nil), // 65: proto.GetRuleConfigContent.Response
	(*EvaluateExpr_Option)(nil),           // 66: proto.EvaluateExpr.Option
	(*EvaluateExpr_Request)(nil),          // 67: proto.EvaluateExpr.Request
	(*EvaluateExpr_Response)(nil),         // 68: proto.EvaluateExpr.Response
	(*EmitIssue_Rule)(nil),                // 69: proto.EmitIssue.Rule
	(*EmitIssue_Request)(nil),             // 70: proto.EmitIssue.Request
	(*EmitIssue_Response)(nil),            // 71: proto.EmitIssue.Response
	(*ApplyChanges_Request)(nil),          // 72: proto.ApplyChanges.Request
	(*ApplyChanges_Response)(nil),         // 73: proto.ApplyChanges.Response
	nil,                                   // 74: proto.ApplyChanges.Request.ChangesEntry
	(*BodySchema_Attribute)(nil),          // 75: proto.BodySchema.Attribute
	(*BodySchema_Block)(nil),              // 76: proto.BodySchema.Block
	(*BodyContent_Attribute)(nil),         // 77: proto.BodyContent.Attribute
	(*BodyContent_Block)(nil),             // 78: proto.BodyContent.Block
	nil,                                   // 79: proto.BodyContent.AttributesEntry
	(*Range_Pos)(nil),                     // 80: proto.Range.Pos
	(*AttributePath_Step)(nil),            // 81: proto.AttributePath.Step
}
var file_tflint_proto_depIdxs = []int32{
	75, // 0: proto.BodySchema.attributes:type_name -> proto.BodySchema.Attribute
	76, // 1: proto.BodySchema.blocks:type_name -> proto.BodySchema.Block
	1,  // 2: proto.BodySchema.Mode:type_name -> proto.SchemaMode
	79, // 3: proto.BodyContent.attributes:type_name -> proto.BodyContent.AttributesEntry
	78, // 4: proto.BodyContent.blocks:type_name -> proto.BodyContent.Block
	26, // 5: proto.Expression.range:type_name -> proto.Range
	28, // 6: proto.Expression.value_marks:type_name -> proto.ValueMark
	80, // 7: proto.Range.start:type_name -> proto.Range.Pos
	80, // 8: proto.Range.end:type_name -> proto.Range.Pos
	81, // 9: proto.AttributePath.steps:type_name -> proto.AttributePath.Step
	27, // 10: proto.ValueMark.path:type_name -> proto.AttributePath
	2,  // 11: proto.ErrorDetail.code:type_name -> proto.ErrorCode
	23, // 12: proto.GetConfigSchema.Response.schema:type_name -> proto.BodySchema
	46, // 13: proto.ApplyGlobalConfig.Config.rules:type_name -> proto.ApplyGlobalConfig.Config.RulesEntry
	42, // 14: proto.ApplyGlobalConfig.Request.config:type_name -> proto.ApplyGlobalConfig.Config
	43, // 15: proto.ApplyGlobalConfig.Config.RulesEntry.value:type_name -> proto.ApplyGlobalConfig.RuleConfig
	24, // 16: proto.ApplyConfig.Request.content:type_name -> proto.BodyContent
	0,  // 17: proto.GetModuleContent.Option.module_ctx:type_name -> proto.ModuleCtxType
	55, // 18: proto.GetModuleContent.Option.hint:type_name -> proto.GetModuleContent.Hint
	3,  // 19: proto.GetModuleContent.Option.expand_mode:type_name -> proto.GetModuleContent.ExpandMode
	23, // 20: proto.GetModuleContent.Request.schema:type_name -> proto.BodySchema
	56, // 21: proto.GetModuleContent.Request.option:type_name -> proto.GetModuleContent.Option
	24, // 22: proto.GetModuleContent.Response.content:type_name -> proto.BodyContent
	63, // 23: proto.GetFiles.Response.files:type_name -> proto.GetFiles.Response.FilesEntry
	23, // 24: proto.GetRuleConfigContent.Request.schema:type_name -> proto.BodySchema
	24, // 25: proto.GetRuleConfigContent.Response.content:type_name -> proto.BodyContent
	0,  // 26: proto.EvaluateExpr.Option.module_ctx:type_name -> proto.ModuleCtxType
	66, // 27: proto.EvaluateExpr.Request.option:type_name -> proto.EvaluateExpr.Option
	25, // 28: proto.EvaluateExpr.Request.expression:type_name -> proto.Expression
	28, // 29: proto.EvaluateExpr.Response.marks:type_name -> proto.ValueMark
	4,  // 30: proto.EmitIssue.Rule.severity:type_name -> proto.EmitIssue.Severity
	69, // 31: proto.EmitIssue.Request.rule:type_name -> proto.EmitIssue.Rule
	26, // 32: proto.EmitIssue.Request.range:type_name -> proto.Range
	74, // 33: proto.ApplyChanges.Request.changes:type_name -> proto.ApplyChanges.Request.ChangesEntry
	23, // 34: proto.BodySchema.Block.body:type_name -> proto.BodySchema
	26, // 35: proto.BodyContent.Attribute.range:type_name -> proto.Range
	26, // 36: proto.BodyContent.Attribute.name_range:type_name -> proto.Range
	25, // 37: proto.BodyContent.Attribute.expression:type_name -> proto.Expression
	24, // 38: proto.BodyContent.Block.body:type_name -> proto.BodyContent
	26, // 39: proto.BodyContent.Block.def_range:type_name -> proto.Range
	26, // 40: proto.BodyContent.Block.type_range:type_name -> proto.Range
	26, // 41: proto.BodyContent.Block.label_ranges:type_name -> proto.Range
	77, // 42: proto.BodyContent.AttributesEntry.value:type_name -> proto.BodyContent.Attribute
	30, // 43: proto.RuleSet.GetName:input_type -> proto.GetName.Request
	32, // 44: proto.RuleSet.GetVersion:input_type -> proto.GetVersion.Request
	34, // 45: proto.RuleSet.GetVersionConstraint:input_type -> proto.GetVersionConstraint.Request
	36, // 46: proto.RuleSet.GetSDKVersion:input_type -> proto.GetSDKVersion.Request
	38, // 47: proto.RuleSet.GetRuleNames:input_type -> proto.GetRuleNames.Request
	40, // 48: proto.RuleSet.GetConfigSchema:input_type -> proto.GetConfigSchema.Request
	44, // 49: proto.RuleSet.ApplyGlobalConfig:input_type -> proto.ApplyGlobalConfig.Request
	47, // 50: proto.RuleSet.ApplyConfig:input_type -> proto.ApplyConfig.Request
	49, // 51: proto.RuleSet.Check:input_type -> proto.Check.Request
	51, // 52: proto.Runner.GetOriginalwd:input_type -> proto.GetOriginalwd.Request
	53, // 53: proto.Runner.GetModulePath:input_type -> proto.GetModulePath.Request
	57, // 54: proto.Runner.GetModuleContent:input_type -> proto.GetModuleContent.Request
	59, // 55: proto.Runner.GetFile:input_type -> proto.GetFile.Request
	61, // 56: proto.Runner.GetFiles:input_type -> proto.GetFiles.Request
	64, // 57: proto.Runner.GetRuleConfigContent:input_type -> proto.GetRuleConfigContent.Request
	67, // 58: proto.Runner.EvaluateExpr:input_type -> proto.EvaluateExpr.Request
	70, // 59: proto.Runner.EmitIssue:input_type -> proto.EmitIssue.Request
	72, // 60: proto.Runner.ApplyChanges:input_type -> proto.ApplyChanges.Request
	31, // 61: proto.RuleSet.GetName:output_type -> proto.GetName.Response
	33, // 62: proto.RuleSet.GetVersion:output_type -> proto.GetVersion.Response
	35, // 63: proto.RuleSet.GetVersionConstraint:output_type -> proto.GetVersionConstraint.Response
	37, // 64: proto.RuleSet.GetSDKVersion:output_type -> proto.GetSDKVersion.Response
	39, // 65: proto.RuleSet.GetRuleNames:output_type -> proto.GetRuleNames.Response
	41, // 66: proto.RuleSet.GetConfigSchema:output_type -> proto.GetConfigSchema.Response
	45, // 67: proto.RuleSet.ApplyGlobalConfig:output_type -> proto.ApplyGlobalConfig.Response
	48, // 68: proto.RuleSet.ApplyConfig:output_type -> proto.ApplyConfig.Response
	50, // 69: proto.RuleSet.Check:output_type -> proto.Check.Response
	52, // 70: proto.Runner.GetOriginalwd:output_type -> proto.GetOriginalwd.Response
	54, // 71: proto.Runner.GetModulePath:output_type -> proto.GetModulePath.Response
	58, // 72: proto.Runner.GetModuleContent:output_type -> proto.GetModuleContent.Response
	60, // 73: proto.Runner.GetFile:output_type -> proto.GetFile.Response
	62, // 74: proto.Runner.GetFiles:output_type -> proto.GetFiles.Response
	65, // 75: proto.Runner.GetRuleConfigContent:output_type -> proto.GetRuleConfigContent.Response
	68, // 76: proto.Runner.EvaluateExpr:output_type -> proto.EvaluateExpr.Response
	71, // 77: proto.Runner.EmitIssue:output_type -> proto.EmitIssue.Response
	73, // 78: proto.Runner.ApplyChanges:output_type -> proto.ApplyChanges.Response
	61, // [61:79] is the sub-list for method output_type
	43, // [43:61] is the sub-list for method input_type
	43, // [43:43] is the sub-list for extension type_name
	43, // [43:43] is the sub-list for extension extendee
	0,  // [0:43] is the sub-list for field type_name
}

func init() { file_tflint_proto_init() }
func file_tflint_proto_init() {
	if File_tflint_proto != nil {
		return
	}
	file_tflint_proto_msgTypes[76].OneofWrappers = []any{
		(*AttributePath_Step_AttributeName)(nil),
		(*AttributePath_Step_ElementKeyString)(nil),
		(*AttributePath_Step_ElementKeyInt)(nil),
	}
	type x struct{}
	out := protoimpl.TypeBuilder{
		File: protoimpl.DescBuilder{
			GoPackagePath: reflect.TypeOf(x{}).PkgPath(),
			RawDescriptor: file_tflint_proto_rawDesc,
			NumEnums:      5,
			NumMessages:   77,
			NumExtensions: 0,
			NumServices:   2,
		},
		GoTypes:           file_tflint_proto_goTypes,
		DependencyIndexes: file_tflint_proto_depIdxs,
		EnumInfos:         file_tflint_proto_enumTypes,
		MessageInfos:      file_tflint_proto_msgTypes,
	}.Build()
	File_tflint_proto = out.File
	file_tflint_proto_rawDesc = nil
	file_tflint_proto_goTypes = nil
	file_tflint_proto_depIdxs = nil
}
